"""
Python module generated from Java source file com.google.common.hash.PrimitiveSink

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.hash import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.nio.charset import Charset
from typing import Any, Callable, Iterable, Tuple


class PrimitiveSink:
    """
    An object which can receive a stream of primitive values.

    Author(s)
    - Kevin Bourrillion

    Since
    - 12.0 (in 11.0 as `Sink`)
    """

    def putByte(self, b: int) -> "PrimitiveSink":
        """
        Puts a byte into this sink.

        Arguments
        - b: a byte

        Returns
        - this instance
        """
        ...


    def putBytes(self, bytes: list[int]) -> "PrimitiveSink":
        """
        Puts an array of bytes into this sink.

        Arguments
        - bytes: a byte array

        Returns
        - this instance
        """
        ...


    def putBytes(self, bytes: list[int], off: int, len: int) -> "PrimitiveSink":
        """
        Puts a chunk of an array of bytes into this sink. `bytes[off]` is the first byte written,
        `bytes[off + len - 1]` is the last.

        Arguments
        - bytes: a byte array
        - off: the start offset in the array
        - len: the number of bytes to write

        Returns
        - this instance

        Raises
        - IndexOutOfBoundsException: if `off < 0` or `off + len > bytes.length` or
            `len < 0`
        """
        ...


    def putBytes(self, bytes: "ByteBuffer") -> "PrimitiveSink":
        """
        Puts the remaining bytes of a byte buffer into this sink. `bytes.position()` is the first
        byte written, `bytes.limit() - 1` is the last. The position of the buffer will be equal
        to the limit when this method returns.

        Arguments
        - bytes: a byte buffer

        Returns
        - this instance

        Since
        - 23.0
        """
        ...


    def putShort(self, s: int) -> "PrimitiveSink":
        """
        Puts a short into this sink.
        """
        ...


    def putInt(self, i: int) -> "PrimitiveSink":
        """
        Puts an int into this sink.
        """
        ...


    def putLong(self, l: int) -> "PrimitiveSink":
        """
        Puts a long into this sink.
        """
        ...


    def putFloat(self, f: float) -> "PrimitiveSink":
        """
        Puts a float into this sink.
        """
        ...


    def putDouble(self, d: float) -> "PrimitiveSink":
        """
        Puts a double into this sink.
        """
        ...


    def putBoolean(self, b: bool) -> "PrimitiveSink":
        """
        Puts a boolean into this sink.
        """
        ...


    def putChar(self, c: str) -> "PrimitiveSink":
        """
        Puts a character into this sink.
        """
        ...


    def putUnencodedChars(self, charSequence: "CharSequence") -> "PrimitiveSink":
        """
        Puts each 16-bit code unit from the CharSequence into this sink.
        
        **Warning:** This method will produce different output than most other languages do when
        running on the equivalent input. For cross-language compatibility, use .putString,
        usually with a charset of UTF-8. For other use cases, use `putUnencodedChars`.

        Since
        - 15.0 (since 11.0 as putString(CharSequence))
        """
        ...


    def putString(self, charSequence: "CharSequence", charset: "Charset") -> "PrimitiveSink":
        """
        Puts a string into this sink using the given charset.
        
        **Warning:** This method, which reencodes the input before processing it, is useful only
        for cross-language compatibility. For other use cases, prefer .putUnencodedChars, which
        is faster, produces the same output across Java releases, and processes every `char` in
        the input, even if some are invalid.
        """
        ...



"""
Python module generated from Java source file com.google.thirdparty.publicsuffix.PublicSuffixType

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.annotations import GwtCompatible
from com.google.thirdparty.publicsuffix import *
from enum import Enum
from typing import Any, Callable, Iterable, Tuple


class PublicSuffixType(Enum):
    """
    **Do not use this class directly. For access to public-suffix information, use com.google.common.net.InternetDomainName.**
    
    Specifies the type of a top-level domain definition.

    Since
    - 23.3
    """

    PRIVATE = (':', ',')
    """
    Public suffix that is provided by a private company, e.g. "blogspot.com"
    """
    REGISTRY = ('!', '?')
    """
    Public suffix that is backed by an ICANN-style domain name registry
    """



"""
Python module generated from Java source file com.google.common.collect.EnumBiMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.util import EnumMap
from typing import Any, Callable, Iterable, Tuple


class EnumBiMap(AbstractBiMap):
    """
    A `BiMap` backed by two `EnumMap` instances. Null keys and values are not permitted.
    An `EnumBiMap` and its inverse are both serializable.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#bimap">`BiMap`</a>.

    Author(s)
    - Mike Bostock

    Since
    - 2.0
    """

    @staticmethod
    def create(keyType: type["K"], valueType: type["V"]) -> "EnumBiMap"["K", "V"]:
        """
        Returns a new, empty `EnumBiMap` using the specified key and value types.

        Arguments
        - keyType: the key type
        - valueType: the value type
        """
        ...


    @staticmethod
    def create(map: dict["K", "V"]) -> "EnumBiMap"["K", "V"]:
        """
        Returns a new bimap with the same mappings as the specified map. If the specified map is an
        `EnumBiMap`, the new bimap has the same types as the provided map. Otherwise, the
        specified map must contain at least one mapping, in order to determine the key and value types.

        Arguments
        - map: the map whose mappings are to be placed in this map

        Raises
        - IllegalArgumentException: if map is not an `EnumBiMap` instance and contains no
            mappings
        """
        ...


    def keyType(self) -> type["K"]:
        """
        Returns the associated key type.
        """
        ...


    def valueType(self) -> type["V"]:
        """
        Returns the associated value type.
        """
        ...



"""
Python module generated from Java source file org.bukkit.help.HelpTopic

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import CommandSender
from org.bukkit.entity import Player
from org.bukkit.help import *
from typing import Any, Callable, Iterable, Tuple


class HelpTopic:
    """
    HelpTopic implementations are displayed to the user when the user uses the
    /help command.
    
    Custom implementations of this class can work at two levels. A simple
    implementation only needs to set the value of `name`, `shortText`, and `fullText` in the constructor. This base class will
    take care of the rest.
    
    Complex implementations can be created by overriding the behavior of all
    the methods in this class.
    """

    def canSee(self, player: "CommandSender") -> bool:
        """
        Determines if a Player is allowed to see this help topic.
        
        HelpTopic implementations should take server administrator wishes into
        account as set by the HelpTopic.amendCanSee(String) function.

        Arguments
        - player: The Player in question.

        Returns
        - True of the Player can see this help topic, False otherwise.
        """
        ...


    def amendCanSee(self, amendedPermission: str) -> None:
        """
        Allows the server administrator to override the permission required to
        see a help topic.
        
        HelpTopic implementations should take this into account when
        determining topic visibility on the HelpTopic.canSee(org.bukkit.command.CommandSender) function.

        Arguments
        - amendedPermission: The permission node the server administrator
            wishes to apply to this topic.
        """
        ...


    def getName(self) -> str:
        """
        Returns the name of this help topic.

        Returns
        - The topic name.
        """
        ...


    def getShortText(self) -> str:
        """
        Returns a brief description that will be displayed in the topic index.

        Returns
        - A brief topic description.
        """
        ...


    def getFullText(self, forWho: "CommandSender") -> str:
        """
        Returns the full description of this help topic that is displayed when
        the user requests this topic's details.
        
        The result will be paginated to properly fit the user's client.

        Arguments
        - forWho: The player or console requesting the full text. Useful
            for further security trimming the command's full text based on
            sub-permissions in custom implementations.

        Returns
        - A full topic description.
        """
        ...


    def amendTopic(self, amendedShortText: str, amendedFullText: str) -> None:
        """
        Allows the server admin (or another plugin) to add or replace the
        contents of a help topic.
        
        A null in either parameter will leave that part of the topic unchanged.
        In either amending parameter, the string <text> is replaced
        with the existing contents in the help topic. Use this to append or
        prepend additional content into an automatically generated help topic.

        Arguments
        - amendedShortText: The new topic short text to use, or null to
            leave alone.
        - amendedFullText: The new topic full text to use, or null to leave
            alone.
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.NetworkConnections

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class NetworkConnections:
    """
    An interface for representing and manipulating an origin node's adjacent nodes and incident edges
    in a Network.
    
    Type `<N>`: Node parameter type
    
    Type `<E>`: Edge parameter type

    Author(s)
    - James Sexton
    """

    def adjacentNodes(self) -> set["N"]:
        ...


    def predecessors(self) -> set["N"]:
        ...


    def successors(self) -> set["N"]:
        ...


    def incidentEdges(self) -> set["E"]:
        ...


    def inEdges(self) -> set["E"]:
        ...


    def outEdges(self) -> set["E"]:
        ...


    def edgesConnecting(self, node: "N") -> set["E"]:
        """
        Returns the set of edges connecting the origin node to `node`. For networks without
        parallel edges, this set cannot be of size greater than one.
        """
        ...


    def adjacentNode(self, edge: "E") -> "N":
        """
        Returns the node that is adjacent to the origin node along `edge`.
        
        In the directed case, `edge` is assumed to be an outgoing edge.
        """
        ...


    def removeInEdge(self, edge: "E", isSelfLoop: bool) -> "N":
        """
        Remove `edge` from the set of incoming edges. Returns the former predecessor node.
        
        In the undirected case, returns `null` if `isSelfLoop` is True.
        """
        ...


    def removeOutEdge(self, edge: "E") -> "N":
        """
        Remove `edge` from the set of outgoing edges. Returns the former successor node.
        """
        ...


    def addInEdge(self, edge: "E", node: "N", isSelfLoop: bool) -> None:
        """
        Add `edge` to the set of incoming edges. Implicitly adds `node` as a predecessor.
        """
        ...


    def addOutEdge(self, edge: "E", node: "N") -> None:
        """
        Add `edge` to the set of outgoing edges. Implicitly adds `node` as a successor.
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.components.JukeboxPlayableComponent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import JukeboxSong
from org.bukkit import NamespacedKey
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.inventory.meta.components import *
from typing import Any, Callable, Iterable, Tuple


class JukeboxPlayableComponent(ConfigurationSerializable):
    """
    Represents a component which can be inserted into a jukebox.
    """

    def getSong(self) -> "JukeboxSong":
        """
        Gets the song assigned to this component.

        Returns
        - song, or null if the song does not exist on the server
        """
        ...


    def getSongKey(self) -> "NamespacedKey":
        """
        Gets the key of the song assigned to this component.

        Returns
        - the song key
        """
        ...


    def setSong(self, song: "JukeboxSong") -> None:
        """
        Sets the song assigned to this component.

        Arguments
        - song: the song
        """
        ...


    def setSongKey(self, song: "NamespacedKey") -> None:
        """
        Sets the key of the song assigned to this component.

        Arguments
        - song: the song key
        """
        ...


    def isShowInTooltip(self) -> bool:
        """
        Gets if the song will show in the item tooltip.

        Returns
        - if the song will show in the tooltip
        """
        ...


    def setShowInTooltip(self, show: bool) -> None:
        """
        Sets if the song will show in the item tooltip.

        Arguments
        - show: True if the song will show in the tooltip
        """
        ...



from .ConcurrentHashMap import ConcurrentHashMap
from .ConcurrentMap import ConcurrentMap
from .ConcurrentNavigableMap import ConcurrentNavigableMap
from .ConcurrentSkipListMap import ConcurrentSkipListMap
from .Callable import Callable
from .ScheduledExecutorService import ScheduledExecutorService
from .ScheduledFuture import ScheduledFuture
from .TimeUnit import TimeUnit
from .ExecutionException import ExecutionException
from .ExecutorService import ExecutorService
from .Executors import Executors
from .Future import Future
from .TimeoutException import TimeoutException
from .BlockingQueue import BlockingQueue
from .CancellationException import CancellationException
from .CountDownLatch import CountDownLatch
from .Semaphore import Semaphore
from .RunnableFuture import RunnableFuture
from .ThreadFactory import ThreadFactory
from .Executor import Executor
from .RejectedExecutionException import RejectedExecutionException
from .Delayed import Delayed
from .ScheduledThreadPoolExecutor import ScheduledThreadPoolExecutor
from .ThreadPoolExecutor import ThreadPoolExecutor
from .FutureTask import FutureTask
from .CopyOnWriteArraySet import CopyOnWriteArraySet
from .BlockingDeque import BlockingDeque
from .AbstractExecutorService import AbstractExecutorService
from .ConcurrentLinkedQueue import ConcurrentLinkedQueue
from .ArrayBlockingQueue import ArrayBlockingQueue
from .LinkedBlockingDeque import LinkedBlockingDeque
from .LinkedBlockingQueue import LinkedBlockingQueue
from .PriorityBlockingQueue import PriorityBlockingQueue
from .SynchronousQueue import SynchronousQueue
from .CopyOnWriteArrayList import CopyOnWriteArrayList
from .CompletableFuture import CompletableFuture


"""
Python module generated from Java source file com.google.common.graph.GraphsBridgeMethods

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.graph import *
from typing import Any, Callable, Iterable, Tuple


class GraphsBridgeMethods:
    """
    Supertype for Graphs, containing the old signatures of methods whose signatures we've
    changed. This provides binary compatibility for users who compiled against the old signatures.
    """

    @staticmethod
    def transitiveClosure(graph: "Graph"["N"]) -> "Graph"["N"]:
        ...


    @staticmethod
    def reachableNodes(graph: "Graph"["N"], node: "N") -> set["N"]:
        ...



"""
Python module generated from Java source file org.bukkit.entity.ChestedHorse

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class ChestedHorse(AbstractHorse):
    """
    Represents Horse-like creatures which can carry an inventory.
    """

    def isCarryingChest(self) -> bool:
        """
        Gets whether the horse has a chest equipped.

        Returns
        - True if the horse has chest storage
        """
        ...


    def setCarryingChest(self, chest: bool) -> None:
        """
        Sets whether the horse has a chest equipped. Removing a chest will also
        clear the chest's inventory.

        Arguments
        - chest: True if the horse should have a chest
        """
        ...



"""
Python module generated from Java source file org.bukkit.damage.DeathMessageType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.damage import *
from typing import Any, Callable, Iterable, Tuple


class DeathMessageType(Enum):
    """
    Represents a type of death message used by a DamageSource.
    """

    DEFAULT = 0
    """
    No special death message logic is applied.
    """
    FALL_VARIANTS = 1
    """
    Shows a variant of fall damage death instead of a regular death message.
    
    **Example:** death.fell.assist.item
    """
    INTENTIONAL_GAME_DESIGN = 2
    """
    Shows the intentional game design death message instead of a regular
    death message.
    """



"""
Python module generated from Java source file com.google.common.base.Defaults

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.base import *
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Defaults:
    """
    This class provides default values for all Java types, as defined by the JLS.

    Author(s)
    - Ben Yu

    Since
    - 1.0
    """

    @staticmethod
    def defaultValue(type: type["T"]) -> "T":
        """
        Returns the default value of `type` as defined by JLS --- `0` for numbers, `False` for `boolean` and `'\0'` for `char`. For non-primitive types and
        `void`, `null` is returned.
        """
        ...



from .CrafterView import CrafterView
from .BeaconView import BeaconView
from .StonecutterView import StonecutterView
from .FurnaceView import FurnaceView
from .MerchantView import MerchantView
from .LecternView import LecternView
from .BrewingStandView import BrewingStandView
from .EnchantmentView import EnchantmentView
from .AnvilView import AnvilView
from .LoomView import LoomView


"""
Python module generated from Java source file org.bukkit.event.entity.PigZombieAngerEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import PigZombie
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class PigZombieAngerEvent(EntityEvent, Cancellable):
    """
    Called when a Pig Zombie is angered by another entity.
    
    If the event is cancelled, the pig zombie will not be angered.
    """

    def __init__(self, pigZombie: "PigZombie", target: "Entity", newAnger: int):
        ...


    def getTarget(self) -> "Entity":
        """
        Gets the entity (if any) which triggered this anger update.

        Returns
        - triggering entity, or null
        """
        ...


    def getNewAnger(self) -> int:
        """
        Gets the new anger resulting from this event.

        Returns
        - new anger

        See
        - PigZombie.getAnger()
        """
        ...


    def setNewAnger(self, newAnger: int) -> None:
        """
        Sets the new anger resulting from this event.

        Arguments
        - newAnger: the new anger

        See
        - PigZombie.setAnger(int)
        """
        ...


    def getEntity(self) -> "PigZombie":
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.util.Currency

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import BufferedInputStream
from java.io import DataInputStream
from java.io import File
from java.io import FileReader
from java.io import IOException
from java.io import InputStream
from java.io import Serializable
from java.security import AccessController
from java.security import PrivilegedAction
from java.text import ParseException
from java.text import SimpleDateFormat
from java.util import *
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from java.util.regex import Matcher
from java.util.regex import Pattern
from java.util.spi import CurrencyNameProvider
from java.util.stream import Collectors
from jdk.internal.util import StaticProperty
from sun.util.locale.provider import CalendarDataUtility
from sun.util.locale.provider import LocaleServiceProviderPool
from sun.util.logging import PlatformLogger
from typing import Any, Callable, Iterable, Tuple


class Currency(Serializable):
    """
    Represents a currency. Currencies are identified by their ISO 4217 currency
    codes. Visit the <a href="http://www.iso.org/iso/home/standards/currency_codes.htm">
    ISO web site</a> for more information.
    
    The class is designed so that there's never more than one
    `Currency` instance for any given currency. Therefore, there's
    no public constructor. You obtain a `Currency` instance using
    the `getInstance` methods.
    
    Users can supersede the Java runtime currency data by means of the system
    property java.util.currency.data. If this system property is
    defined then its value is the location of a properties file, the contents of
    which are key/value pairs of the ISO 3166 country codes and the ISO 4217
    currency data respectively.  The value part consists of three ISO 4217 values
    of a currency, i.e., an alphabetic code, a numeric code, and a minor unit.
    Those three ISO 4217 values are separated by commas.
    The lines which start with '#'s are considered comment lines. An optional UTC
    timestamp may be specified per currency entry if users need to specify a
    cutover date indicating when the new data comes into effect. The timestamp is
    appended to the end of the currency properties and uses a comma as a separator.
    If a UTC datestamp is present and valid, the JRE will only use the new currency
    properties if the current UTC date is later than the date specified at class
    loading time. The format of the timestamp must be of ISO 8601 format :
    `'yyyy-MM-dd'T'HH:mm:ss'`. For example,
    
    `
    #Sample currency properties
    JP=JPZ,999,0
    `
    
    will supersede the currency data for Japan. If JPZ is one of the existing
    ISO 4217 currency code referred by other countries, the existing
    JPZ currency data is updated with the given numeric code and minor
    unit value.
    
    
    `
    #Sample currency properties with cutover date
    JP=JPZ,999,0,2014-01-01T00:00:00
    `
    
    will supersede the currency data for Japan if `Currency` class is loaded after
    1st January 2014 00:00:00 GMT.
    
    Where syntactically malformed entries are encountered, the entry is ignored
    and the remainder of entries in file are processed. For instances where duplicate
    country code entries exist, the behavior of the Currency information for that
    `Currency` is undefined and the remainder of entries in file are processed.
    
    If multiple property entries with same currency code but different numeric code
    and/or minor unit are encountered, those entries are ignored and the remainder
    of entries in file are processed.
    
    
    It is recommended to use java.math.BigDecimal class while dealing
    with `Currency` or monetary values as it provides better handling of floating
    point numbers and their operations.

    See
    - java.math.BigDecimal

    Since
    - 1.4
    """

    @staticmethod
    def getInstance(currencyCode: str) -> "Currency":
        """
        Returns the `Currency` instance for the given currency code.

        Arguments
        - currencyCode: the ISO 4217 code of the currency

        Returns
        - the `Currency` instance for the given currency code

        Raises
        - NullPointerException: if `currencyCode` is null
        - IllegalArgumentException: if `currencyCode` is not
        a supported ISO 4217 code.
        """
        ...


    @staticmethod
    def getInstance(locale: "Locale") -> "Currency":
        """
        Returns the `Currency` instance for the country of the
        given locale. The language and variant components of the locale
        are ignored. The result may vary over time, as countries change their
        currencies. For example, for the original member countries of the
        European Monetary Union, the method returns the old national currencies
        until December 31, 2001, and the Euro from January 1, 2002, local time
        of the respective countries.
        
        If the specified `locale` contains "cu" and/or "rg"
        <a href="./Locale.html#def_locale_extension">Unicode extensions</a>,
        the instance returned from this method reflects
        the values specified with those extensions. If both "cu" and "rg" are
        specified, the currency from the "cu" extension supersedes the implicit one
        from the "rg" extension.
        
        The method returns `null` for territories that don't
        have a currency, such as Antarctica.

        Arguments
        - locale: the locale for whose country a `Currency`
        instance is needed

        Returns
        - the `Currency` instance for the country of the given
        locale, or `null`

        Raises
        - NullPointerException: if `locale`
        is `null`
        - IllegalArgumentException: if the country of the given `locale`
        is not a supported ISO 3166 country code.
        """
        ...


    @staticmethod
    def getAvailableCurrencies() -> set["Currency"]:
        """
        Gets the set of available currencies.  The returned set of currencies
        contains all of the available currencies, which may include currencies
        that represent obsolete ISO 4217 codes.  The set can be modified
        without affecting the available currencies in the runtime.

        Returns
        - the set of available currencies.  If there is no currency
           available in the runtime, the returned set is empty.

        Since
        - 1.7
        """
        ...


    def getCurrencyCode(self) -> str:
        """
        Gets the ISO 4217 currency code of this currency.

        Returns
        - the ISO 4217 currency code of this currency.
        """
        ...


    def getSymbol(self) -> str:
        """
        Gets the symbol of this currency for the default
        Locale.Category.DISPLAY DISPLAY locale.
        For example, for the US Dollar, the symbol is "$" if the default
        locale is the US, while for other locales it may be "US$". If no
        symbol can be determined, the ISO 4217 currency code is returned.
        
        If the default Locale.Category.DISPLAY DISPLAY locale
        contains "rg" (region override)
        <a href="./Locale.html#def_locale_extension">Unicode extension</a>,
        the symbol returned from this method reflects
        the value specified with that extension.
        
        This is equivalent to calling
        .getSymbol(Locale)
            getSymbol(Locale.getDefault(Locale.Category.DISPLAY)).

        Returns
        - the symbol of this currency for the default
            Locale.Category.DISPLAY DISPLAY locale
        """
        ...


    def getSymbol(self, locale: "Locale") -> str:
        """
        Gets the symbol of this currency for the specified locale.
        For example, for the US Dollar, the symbol is "$" if the specified
        locale is the US, while for other locales it may be "US$". If no
        symbol can be determined, the ISO 4217 currency code is returned.
        
        If the specified `locale` contains "rg" (region override)
        <a href="./Locale.html#def_locale_extension">Unicode extension</a>,
        the symbol returned from this method reflects
        the value specified with that extension.

        Arguments
        - locale: the locale for which a display name for this currency is
        needed

        Returns
        - the symbol of this currency for the specified locale

        Raises
        - NullPointerException: if `locale` is null
        """
        ...


    def getDefaultFractionDigits(self) -> int:
        """
        Gets the default number of fraction digits used with this currency.
        Note that the number of fraction digits is the same as ISO 4217's
        minor unit for the currency.
        For example, the default number of fraction digits for the Euro is 2,
        while for the Japanese Yen it's 0.
        In the case of pseudo-currencies, such as IMF Special Drawing Rights,
        -1 is returned.

        Returns
        - the default number of fraction digits used with this currency
        """
        ...


    def getNumericCode(self) -> int:
        """
        Returns the ISO 4217 numeric code of this currency.

        Returns
        - the ISO 4217 numeric code of this currency

        Since
        - 1.7
        """
        ...


    def getNumericCodeAsString(self) -> str:
        """
        Returns the 3 digit ISO 4217 numeric code of this currency as a `String`.
        Unlike .getNumericCode(), which returns the numeric code as `int`,
        this method always returns the numeric code as a 3 digit string.
        e.g. a numeric value of 32 would be returned as "032",
        and a numeric value of 6 would be returned as "006".

        Returns
        - the 3 digit ISO 4217 numeric code of this currency as a `String`

        Since
        - 9
        """
        ...


    def getDisplayName(self) -> str:
        """
        Gets the name that is suitable for displaying this currency for
        the default Locale.Category.DISPLAY DISPLAY locale.
        If there is no suitable display name found
        for the default locale, the ISO 4217 currency code is returned.
        
        This is equivalent to calling
        .getDisplayName(Locale)
            getDisplayName(Locale.getDefault(Locale.Category.DISPLAY)).

        Returns
        - the display name of this currency for the default
            Locale.Category.DISPLAY DISPLAY locale

        Since
        - 1.7
        """
        ...


    def getDisplayName(self, locale: "Locale") -> str:
        """
        Gets the name that is suitable for displaying this currency for
        the specified locale.  If there is no suitable display name found
        for the specified locale, the ISO 4217 currency code is returned.

        Arguments
        - locale: the locale for which a display name for this currency is
        needed

        Returns
        - the display name of this currency for the specified locale

        Raises
        - NullPointerException: if `locale` is null

        Since
        - 1.7
        """
        ...


    def toString(self) -> str:
        """
        Returns the ISO 4217 currency code of this currency.

        Returns
        - the ISO 4217 currency code of this currency
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.FutureCallback

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from java.util.concurrent import ExecutionException
from java.util.concurrent import Future
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class FutureCallback:
    """
    A callback for accepting the results of a java.util.concurrent.Future computation
    asynchronously.
    
    To attach to a ListenableFuture use Futures.addCallback.

    Author(s)
    - Anthony Zana

    Since
    - 10.0
    """

    def onSuccess(self, result: "V") -> None:
        """
        Invoked with the result of the `Future` computation when it is successful.
        """
        ...


    def onFailure(self, t: "Throwable") -> None:
        """
        Invoked when a `Future` computation fails or is canceled.
        
        If the future's Future.get() get method throws an ExecutionException, then
        the cause is passed to this method. Any other thrown object is passed unaltered.
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.MutableGraph

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from typing import Any, Callable, Iterable, Tuple


class MutableGraph(Graph):
    """
    A subinterface of Graph which adds mutation methods. When mutation is not required, users
    should prefer the Graph interface.
    
    Type `<N>`: Node parameter type

    Author(s)
    - Joshua O'Madadhain

    Since
    - 20.0
    """

    def addNode(self, node: "N") -> bool:
        """
        Adds `node` if it is not already present.
        
        **Nodes must be unique**, just as `Map` keys must be. They must also be non-null.

        Returns
        - `True` if the graph was modified as a result of this call
        """
        ...


    def putEdge(self, nodeU: "N", nodeV: "N") -> bool:
        """
        Adds an edge connecting `nodeU` to `nodeV` if one is not already present.
        
        If the graph is directed, the resultant edge will be directed; otherwise, it will be
        undirected.
        
        If `nodeU` and `nodeV` are not already present in this graph, this method will
        silently .addNode(Object) add `nodeU` and `nodeV` to the graph.

        Returns
        - `True` if the graph was modified as a result of this call

        Raises
        - IllegalArgumentException: if the introduction of the edge would violate .allowsSelfLoops()
        """
        ...


    def putEdge(self, endpoints: "EndpointPair"["N"]) -> bool:
        """
        Adds an edge connecting `endpoints` (in the order, if any, specified by `endpoints`) if one is not already present.
        
        If this graph is directed, `endpoints` must be ordered and the added edge will be
        directed; if it is undirected, the added edge will be undirected.
        
        If this graph is directed, `endpoints` must be ordered.
        
        If either or both endpoints are not already present in this graph, this method will silently
        .addNode(Object) add each missing endpoint to the graph.

        Returns
        - `True` if the graph was modified as a result of this call

        Raises
        - IllegalArgumentException: if the introduction of the edge would violate .allowsSelfLoops()
        - IllegalArgumentException: if the endpoints are unordered and the graph is directed

        Since
        - 27.1
        """
        ...


    def removeNode(self, node: "N") -> bool:
        """
        Removes `node` if it is present; all edges incident to `node` will also be removed.

        Returns
        - `True` if the graph was modified as a result of this call
        """
        ...


    def removeEdge(self, nodeU: "N", nodeV: "N") -> bool:
        """
        Removes the edge connecting `nodeU` to `nodeV`, if it is present.

        Returns
        - `True` if the graph was modified as a result of this call
        """
        ...


    def removeEdge(self, endpoints: "EndpointPair"["N"]) -> bool:
        """
        Removes the edge connecting `endpoints`, if it is present.
        
        If this graph is directed, `endpoints` must be ordered.

        Returns
        - `True` if the graph was modified as a result of this call

        Raises
        - IllegalArgumentException: if the endpoints are unordered and the graph is directed

        Since
        - 27.1
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.parser.Production

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.events import Event
from org.yaml.snakeyaml.parser import *
from typing import Any, Callable, Iterable, Tuple


class Production:
    """
    Helper for ParserImpl. A grammar rule to apply given the symbols on top of its stack and
    the next input token

    See
    - <a href="http://en.wikipedia.org/wiki/LL_parser">LL parser</a>
    """

    def produce(self) -> "Event":
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.external.com.google.gdata.util.common.base.Escaper

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.external.com.google.gdata.util.common.base import *
from typing import Any, Callable, Iterable, Tuple


class Escaper:
    """
    An object that converts literal text into a format safe for inclusion in a particular context
    (such as an XML document). Typically (but not always), the inverse process of "unescaping" the
    text is performed automatically by the relevant parser.
    
    
    For example, an XML escaper would convert the literal string `"Foo<Bar>"` into
    `"Foo&lt;Bar&gt;"` to prevent `"<Bar>"` from being confused with an XML tag. When the
    resulting XML document is parsed, the parser API will return this text as the original literal
    string `"Foo<Bar>"`.
    
    
    An `Escaper` instance is required to be stateless, and safe when used concurrently by
    multiple threads.
    
    
    Several popular escapers are defined as constants in the class CharEscapers. To create
    your own escapers, use CharEscaperBuilder, or extend CharEscaper or
    `UnicodeEscaper`.
    """

    def escape(self, string: str) -> str:
        """
        Returns the escaped form of a given literal string.
        
        
        Note that this method may treat input characters differently depending on the specific escaper
        implementation.
        
        - UnicodeEscaper handles <a href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a>
        correctly, including surrogate character pairs. If the input is badly formed the escaper should
        throw IllegalArgumentException.
        - CharEscaper handles Java characters independently and does not verify the input for
        well formed characters. A CharEscaper should not be used in situations where input is not
        guaranteed to be restricted to the Basic Multilingual Plane (BMP).

        Arguments
        - string: the literal string to be escaped

        Returns
        - the escaped form of `string`

        Raises
        - NullPointerException: if `string` is null
        - IllegalArgumentException: if `string` contains badly formed UTF-16 or cannot be
                escaped for any other reason
        """
        ...


    def escape(self, out: "Appendable") -> "Appendable":
        """
        Returns an `Appendable` instance which automatically escapes all text appended to it
        before passing the resulting text to an underlying `Appendable`.
        
        
        Note that this method may treat input characters differently depending on the specific escaper
        implementation.
        
        - UnicodeEscaper handles <a href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a>
        correctly, including surrogate character pairs. If the input is badly formed the escaper should
        throw IllegalArgumentException.
        - CharEscaper handles Java characters independently and does not verify the input for
        well formed characters. A CharEscaper should not be used in situations where input is not
        guaranteed to be restricted to the Basic Multilingual Plane (BMP).

        Arguments
        - out: the underlying `Appendable` to append escaped output to

        Returns
        - an `Appendable` which passes text to `out` after escaping it.
        """
        ...



from .ValueGraphBuilder import ValueGraphBuilder
from .ValueGraph import ValueGraph
from .UndirectedNetworkConnections import UndirectedNetworkConnections
from .UndirectedMultiNetworkConnections import UndirectedMultiNetworkConnections
from .UndirectedGraphConnections import UndirectedGraphConnections
from .Traverser import Traverser
from .SuccessorsFunction import SuccessorsFunction
from .StandardValueGraph import StandardValueGraph
from .StandardNetwork import StandardNetwork
from .StandardMutableValueGraph import StandardMutableValueGraph
from .StandardMutableNetwork import StandardMutableNetwork
from .StandardMutableGraph import StandardMutableGraph
from .PredecessorsFunction import PredecessorsFunction
from .ParametricNullness import ParametricNullness
from .NetworkConnections import NetworkConnections
from .NetworkBuilder import NetworkBuilder
from .Network import Network
from .MutableValueGraph import MutableValueGraph
from .MutableNetwork import MutableNetwork
from .MutableGraph import MutableGraph
from .MultiEdgesConnecting import MultiEdgesConnecting
from .MapRetrievalCache import MapRetrievalCache
from .MapIteratorCache import MapIteratorCache
from .InvalidatableSet import InvalidatableSet
from .IncidentEdgeSet import IncidentEdgeSet
from .ImmutableValueGraph import ImmutableValueGraph
from .ImmutableNetwork import ImmutableNetwork
from .ImmutableGraph import ImmutableGraph
from .GraphsBridgeMethods import GraphsBridgeMethods
from .Graphs import Graphs
from .GraphConstants import GraphConstants
from .GraphConnections import GraphConnections
from .GraphBuilder import GraphBuilder
from .Graph import Graph
from .ForwardingValueGraph import ForwardingValueGraph
from .ForwardingNetwork import ForwardingNetwork
from .ForwardingGraph import ForwardingGraph
from .EndpointPairIterator import EndpointPairIterator
from .EndpointPair import EndpointPair
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .ElementOrder import ElementOrder
from .EdgesConnecting import EdgesConnecting
from .DirectedNetworkConnections import DirectedNetworkConnections
from .DirectedMultiNetworkConnections import DirectedMultiNetworkConnections
from .DirectedGraphConnections import DirectedGraphConnections
from .BaseGraph import BaseGraph
from .AbstractValueGraph import AbstractValueGraph
from .AbstractUndirectedNetworkConnections import AbstractUndirectedNetworkConnections
from .AbstractNetwork import AbstractNetwork
from .AbstractGraphBuilder import AbstractGraphBuilder
from .AbstractGraph import AbstractGraph
from .AbstractDirectedNetworkConnections import AbstractDirectedNetworkConnections
from .AbstractBaseGraph import AbstractBaseGraph


"""
Python module generated from Java source file org.bukkit.event.server.BroadcastMessageEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import CommandSender
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import AsyncPlayerChatEvent
from org.bukkit.event.server import *
from typing import Any, Callable, Iterable, Tuple


class BroadcastMessageEvent(ServerEvent, Cancellable):
    """
    Event triggered for server broadcast messages such as from
    org.bukkit.Server.broadcast(String, String).
    
    **This event behaves similarly to AsyncPlayerChatEvent in that it
    should be async if fired from an async thread. Please see that event for
    further information.**
    """

    def __init__(self, message: str, recipients: set["CommandSender"]):
        ...


    def __init__(self, isAsync: bool, message: str, recipients: set["CommandSender"]):
        ...


    def getMessage(self) -> str:
        """
        Get the message to broadcast.

        Returns
        - Message to broadcast
        """
        ...


    def setMessage(self, message: str) -> None:
        """
        Set the message to broadcast.

        Arguments
        - message: New message to broadcast
        """
        ...


    def getRecipients(self) -> set["CommandSender"]:
        """
        Gets a set of recipients that this chat message will be displayed to.
        
        The set returned is not guaranteed to be mutable and may auto-populate
        on access. Any listener accessing the returned set should be aware that
        it may reduce performance for a lazy set implementation.
        
        Listeners should be aware that modifying the list may throw UnsupportedOperationException if the event caller provides an
        unmodifiable set.

        Returns
        - All CommandSenders who will see this chat message
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerRespawnEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from enum import Enum
from org.bukkit import Location
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerRespawnEvent(PlayerEvent):
    """
    Called when a player respawns.
    """

    def __init__(self, respawnPlayer: "Player", respawnLocation: "Location", isBedSpawn: bool):
        ...


    def __init__(self, respawnPlayer: "Player", respawnLocation: "Location", isBedSpawn: bool, isAnchorSpawn: bool):
        ...


    def __init__(self, respawnPlayer: "Player", respawnLocation: "Location", isBedSpawn: bool, isAnchorSpawn: bool, respawnReason: "RespawnReason"):
        ...


    def getRespawnLocation(self) -> "Location":
        """
        Gets the current respawn location

        Returns
        - Location current respawn location
        """
        ...


    def setRespawnLocation(self, respawnLocation: "Location") -> None:
        """
        Sets the new respawn location

        Arguments
        - respawnLocation: new location for the respawn
        """
        ...


    def isBedSpawn(self) -> bool:
        """
        Gets whether the respawn location is the player's bed.

        Returns
        - True if the respawn location is the player's bed.
        """
        ...


    def isAnchorSpawn(self) -> bool:
        """
        Gets whether the respawn location is the player's respawn anchor.

        Returns
        - True if the respawn location is the player's respawn anchor.
        """
        ...


    def getRespawnReason(self) -> "RespawnReason":
        """
        Gets the reason this respawn event was called.

        Returns
        - the reason the event was called.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class RespawnReason(Enum):
        """
        An enum to specify the reason a respawn event was called.
        """

        DEATH = 0
        """
        When the player dies and presses the respawn button.
        """
        END_PORTAL = 1
        """
        When the player exits the end through the end portal.
        """
        PLUGIN = 2
        """
        When a plugin respawns the player.
        """



"""
Python module generated from Java source file org.bukkit.persistence.PersistentDataType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.persistence import *
from typing import Any, Callable, Iterable, Tuple


class PersistentDataType:
    """
    This class represents an enum with a generic content type. It defines the
    types a custom tag can have.
    
    This interface can be used to create your own custom
    PersistentDataType with different complex types. This may be useful
    for the likes of a UUIDTagType:
    ```
    {@code
    public class UUIDTagType implements PersistentDataType<byte[], UUID> {
    
    Type `<P>`: the primary object type that is stored in the given tag
    
    Type `<C>`: the retrieved object type when applying this tag type

    Unknown Tags
    - public Class<byte[]> getPrimitiveType() {
                return byte[].class;
            }
    - public Class<UUID> getComplexType() {
                return UUID.class;
            }
    - public byte[] toPrimitive(UUID complex, PersistentDataAdapterContext context) {
                ByteBuffer bb = ByteBuffer.wrap(new byte[16]);
                bb.putLong(complex.getMostSignificantBits());
                bb.putLong(complex.getLeastSignificantBits());
                return bb.array();
            }
    - public UUID fromPrimitive(byte[] primitive, PersistentDataAdapterContext context) {
                ByteBuffer bb = ByteBuffer.wrap(primitive);
                long firstLong = bb.getLong();
                long secondLong = bb.getLong();
                return new UUID(firstLong, secondLong);
            }
        }
    }```
    
    Any plugin owned implementation of this interface is required to define one
    of the existing primitive types found in this interface. Notably
    .BOOLEAN is not a primitive type but a convenience type.
    """

    BYTE = PrimitivePersistentDataType<>(Byte.class)
    SHORT = PrimitivePersistentDataType<>(Short.class)
    INTEGER = PrimitivePersistentDataType<>(Integer.class)
    LONG = PrimitivePersistentDataType<>(Long.class)
    FLOAT = PrimitivePersistentDataType<>(Float.class)
    DOUBLE = PrimitivePersistentDataType<>(Double.class)
    BOOLEAN = BooleanPersistentDataType()
    """
    A convenience implementation to convert between Byte and Boolean as there is
    no native implementation for booleans. 
    Any byte value not equal to 0 is considered to be True.
    """
    STRING = PrimitivePersistentDataType<>(String.class)
    BYTE_ARRAY = PrimitivePersistentDataType<>(byte[].class)
    INTEGER_ARRAY = PrimitivePersistentDataType<>(int[].class)
    LONG_ARRAY = PrimitivePersistentDataType<>(long[].class)
    TAG_CONTAINER_ARRAY = PrimitivePersistentDataType<>(PersistentDataContainer[].class)
    """
    Deprecated
    - Use .LIST's ListPersistentDataTypeProvider.dataContainers() instead as
    ListPersistentDataTypes offer full support for primitive types, such as the
    PersistentDataContainer.
    """
    TAG_CONTAINER = PrimitivePersistentDataType<>(PersistentDataContainer.class)
    LIST = ListPersistentDataTypeProvider()
    """
    A data type provider type that itself cannot be used as a
    PersistentDataType.
    
    ListPersistentDataTypeProvider exposes shared persistent data
    types for storing lists of other data types, however.
    
    Its existence in the PersistentDataType interface does not permit
    java.util.List as a primitive type in combination with a plain
    PersistentDataType. java.util.Lists are only valid
    primitive types when used via a ListPersistentDataType.

    See
    - ListPersistentDataTypeProvider
    """


    def getPrimitiveType(self) -> type["P"]:
        """
        Returns the primitive data type of this tag.

        Returns
        - the class
        """
        ...


    def getComplexType(self) -> type["C"]:
        """
        Returns the complex object type the primitive value resembles.

        Returns
        - the class type
        """
        ...


    def toPrimitive(self, complex: "C", context: "PersistentDataAdapterContext") -> "P":
        """
        Returns the primitive data that resembles the complex object passed to
        this method.

        Arguments
        - complex: the complex object instance
        - context: the context this operation is running in

        Returns
        - the primitive value
        """
        ...


    def fromPrimitive(self, primitive: "P", context: "PersistentDataAdapterContext") -> "C":
        """
        Creates a complex object based of the passed primitive value

        Arguments
        - primitive: the primitive value
        - context: the context this operation is running in

        Returns
        - the complex object instance
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerBedLeaveEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.block import Block
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerBedLeaveEvent(PlayerEvent, Cancellable):
    """
    This event is fired when the player is leaving a bed.
    """

    def __init__(self, who: "Player", bed: "Block", setBedSpawn: bool):
        ...


    def getBed(self) -> "Block":
        """
        Returns the bed block involved in this event.

        Returns
        - the bed block involved in this event
        """
        ...


    def shouldSetSpawnLocation(self) -> bool:
        """
        Get if this event should set the new spawn location for the
        Player.
        
        This does not remove any existing spawn location, only prevent it from
        being changed (if True).
        
        To change a Player's spawn location, use
        Player.setBedSpawnLocation(Location).

        Returns
        - True if the spawn location will be changed
        """
        ...


    def setSpawnLocation(self, setBedSpawn: bool) -> None:
        """
        Set if this event should set the new spawn location for the
        Player.
        
        This will not remove any existing spawn location, only prevent it from
        being changed (if True).
        
        To change a Player's spawn location, use
        Player.setBedSpawnLocation(Location).

        Arguments
        - setBedSpawn: True to change the new spawn location
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.JsonNull

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from typing import Any, Callable, Iterable, Tuple


class JsonNull(JsonElement):
    """
    A class representing a JSON `null` value.

    Author(s)
    - Joel Leitch

    Since
    - 1.2
    """

    INSTANCE = JsonNull()
    """
    Singleton for `JsonNull`.

    Since
    - 1.8
    """


    def __init__(self):
        """
        Creates a new `JsonNull` object.

        Deprecated
        - Deprecated since Gson version 1.8, use .INSTANCE instead.
        """
        ...


    def deepCopy(self) -> "JsonNull":
        """
        Returns the same instance since it is an immutable value.

        Since
        - 2.8.2
        """
        ...


    def hashCode(self) -> int:
        """
        All instances of `JsonNull` have the same hash code since they are indistinguishable.
        """
        ...


    def equals(self, other: "Object") -> bool:
        """
        All instances of `JsonNull` are considered equal.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.LinkedHashMultiset

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class LinkedHashMultiset(AbstractMapBasedMultiset):
    """
    A `Multiset` implementation with predictable iteration order. Its iterator orders elements
    according to when the first occurrence of the element was added. When the multiset contains
    multiple instances of an element, those instances are consecutive in the iteration order. If all
    occurrences of an element are removed, after which that element is added to the multiset, the
    element will appear at the end of the iteration.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multiset">`Multiset`</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    @staticmethod
    def create() -> "LinkedHashMultiset"["E"]:
        """
        Creates a new, empty `LinkedHashMultiset` using the default initial capacity.
        """
        ...


    @staticmethod
    def create(distinctElements: int) -> "LinkedHashMultiset"["E"]:
        """
        Creates a new, empty `LinkedHashMultiset` with the specified expected number of distinct
        elements.

        Arguments
        - distinctElements: the expected number of distinct elements

        Raises
        - IllegalArgumentException: if `distinctElements` is negative
        """
        ...


    @staticmethod
    def create(elements: Iterable["E"]) -> "LinkedHashMultiset"["E"]:
        """
        Creates a new `LinkedHashMultiset` containing the specified elements.
        
        This implementation is highly efficient when `elements` is itself a Multiset.

        Arguments
        - elements: the elements that the multiset should contain
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityCombustByBlockEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.entity import Entity
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityCombustByBlockEvent(EntityCombustEvent):
    """
    Called when a block causes an entity to combust.
    """

    def __init__(self, combuster: "Block", combustee: "Entity", duration: int):
        ...


    def __init__(self, combuster: "Block", combustee: "Entity", duration: float):
        ...


    def getCombuster(self) -> "Block":
        """
        The combuster can be lava or a block that is on fire.
        
        WARNING: block may be null.

        Returns
        - the Block that set the combustee alight.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.Multimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import CompatibleWith
from com.google.errorprone.annotations import DoNotMock
from java.util.function import BiConsumer
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Multimap:
    """
    A collection that maps keys to values, similar to Map, but in which each key may be
    associated with *multiple* values. You can visualize the contents of a multimap either as a
    map from keys to *nonempty* collections of values:
    
    
      - a → 1, 2
      - b → 3
    
    
    ... or as a single "flattened" collection of key-value pairs:
    
    
      - a → 1
      - a → 2
      - b → 3
    
    
    **Important:** although the first interpretation resembles how most multimaps are
    *implemented*, the design of the `Multimap` API is based on the *second* form.
    So, using the multimap shown above as an example, the .size is `3`, not `2`,
    and the .values collection is `[1, 2, 3]`, not `[[1, 2], [3]]`. For those
    times when the first style is more useful, use the multimap's .asMap view (or create a
    `Map<K, Collection<V>>` in the first place).
    
    <h3>Example</h3>
    
    The following code:
    
    ````ListMultimap<String, String> multimap = ArrayListMultimap.create();
    for (President pres : US_PRESIDENTS_IN_ORDER) {
      multimap.put(pres.firstName(), pres.lastName());`
    for (String firstName : multimap.keySet()) {
      List<String> lastNames = multimap.get(firstName);
      out.println(firstName + ": " + lastNames);
    }
    }```
    
    ... produces output such as:
    
    ````Zachary: [Taylor]
    John: [Adams, Adams, Tyler, Kennedy]  // Remember, Quincy!
    George: [Washington, Bush, Bush]
    Grover: [Cleveland, Cleveland]        // Two, non-consecutive terms, rep'ing NJ!
    ...````
    
    <h3>Views</h3>
    
    Much of the power of the multimap API comes from the *view collections* it provides.
    These always reflect the latest state of the multimap itself. When they support modification, the
    changes are *write-through* (they automatically update the backing multimap). These view
    collections are:
    
    
      - .asMap, mentioned above
      - .keys, .keySet, .values, .entries, which are similar to the
          corresponding view collections of Map
      - and, notably, even the collection returned by .get get(key) is an active view of
          the values corresponding to `key`
    
    
    The collections returned by the .replaceValues replaceValues and .removeAll
    removeAll methods, which contain values that have just been removed from the multimap, are
    naturally *not* views.
    
    <h3>Subinterfaces</h3>
    
    Instead of using the `Multimap` interface directly, prefer the subinterfaces ListMultimap and SetMultimap. These take their names from the fact that the collections
    they return from `get` behave like (and, of course, implement) List and Set, respectively.
    
    For example, the "presidents" code snippet above used a `ListMultimap`; if it had used a
    `SetMultimap` instead, two presidents would have vanished, and last names might or might
    not appear in chronological order.
    
    **Warning:** instances of type `Multimap` may not implement Object.equals in
    the way you expect. Multimaps containing the same key-value pairs, even in the same order, may or
    may not be equal and may or may not have the same `hashCode`. The recommended subinterfaces
    provide much stronger guarantees.
    
    <h3>Comparison to a map of collections</h3>
    
    Multimaps are commonly used in places where a `Map<K, Collection<V>>` would otherwise
    have appeared. The differences include:
    
    
      - There is no need to populate an empty collection before adding an entry with .put
          put.
      - `get` never returns `null`, only an empty collection.
      - A key is contained in the multimap if and only if it maps to at least one value. Any
          operation that causes a key to have zero associated values has the effect of
          *removing* that key from the multimap.
      - The total entry count is available as .size.
      - Many complex operations become easier; for example, `Collections.min(multimap.values())` finds the smallest value across all keys.
    
    
    <h3>Implementations</h3>
    
    
      - ImmutableListMultimap
      - ImmutableSetMultimap
      - Configure your own mutable multimap with MultimapBuilder
      - LinkedListMultimap (for one unusual kind of mutable `Multimap`)
    
    
    Guava contains a number of other multimap implementations, such as ArrayListMultimap. In
    new code, we recommend using MultimapBuilder instead: It provides better control of how
    keys and values are stored.
    
    <h3>Other Notes</h3>
    
    As with `Map`, the behavior of a `Multimap` is not specified if key objects
    already present in the multimap change in a manner that affects `equals` comparisons. Use
    caution if mutable objects are used as keys in a `Multimap`.
    
    All methods that modify the multimap are optional. The view collections returned by the
    multimap may or may not be modifiable. Any modification method that is not supported will throw
    UnsupportedOperationException.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multimap">`Multimap`</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    def size(self) -> int:
        """
        Returns the number of key-value pairs in this multimap.
        
        **Note:** this method does not return the number of *distinct keys* in the multimap,
        which is given by `keySet().size()` or `asMap().size()`. See the opening section of
        the Multimap class documentation for clarification.
        """
        ...


    def isEmpty(self) -> bool:
        """
        Returns `True` if this multimap contains no key-value pairs. Equivalent to `size()
        == 0`, but can in some cases be more efficient.
        """
        ...


    def containsKey(self, key: "Object") -> bool:
        """
        Returns `True` if this multimap contains at least one key-value pair with the key `key`.
        """
        ...


    def containsValue(self, value: "Object") -> bool:
        """
        Returns `True` if this multimap contains at least one key-value pair with the value
        `value`.
        """
        ...


    def containsEntry(self, key: "Object", value: "Object") -> bool:
        """
        Returns `True` if this multimap contains at least one key-value pair with the key `key` and the value `value`.
        """
        ...


    def put(self, key: "K", value: "V") -> bool:
        """
        Stores a key-value pair in this multimap.
        
        Some multimap implementations allow duplicate key-value pairs, in which case `put`
        always adds a new key-value pair and increases the multimap size by 1. Other implementations
        prohibit duplicates, and storing a key-value pair that's already in the multimap has no effect.

        Returns
        - `True` if the method increased the size of the multimap, or `False` if the
            multimap already contained the key-value pair and doesn't allow duplicates
        """
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        """
        Removes a single key-value pair with the key `key` and the value `value` from this
        multimap, if such exists. If multiple key-value pairs in the multimap fit this description,
        which one is removed is unspecified.

        Returns
        - `True` if the multimap changed
        """
        ...


    def putAll(self, key: "K", values: Iterable["V"]) -> bool:
        """
        Stores a key-value pair in this multimap for each of `values`, all using the same key,
        `key`. Equivalent to (but expected to be more efficient than):
        
        ````for (V value : values) {
          put(key, value);`
        }```
        
        In particular, this is a no-op if `values` is empty.

        Returns
        - `True` if the multimap changed
        """
        ...


    def putAll(self, multimap: "Multimap"["K", "V"]) -> bool:
        """
        Stores all key-value pairs of `multimap` in this multimap, in the order returned by
        `multimap.entries()`.

        Returns
        - `True` if the multimap changed
        """
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> Iterable["V"]:
        """
        Stores a collection of values with the same key, replacing any existing values for that key.
        
        If `values` is empty, this is equivalent to .removeAll(Object) removeAll(key).

        Returns
        - the collection of replaced values, or an empty collection if no values were previously
            associated with the key. The collection *may* be modifiable, but updating it will have
            no effect on the multimap.
        """
        ...


    def removeAll(self, key: "Object") -> Iterable["V"]:
        """
        Removes all values associated with the key `key`.
        
        Once this method returns, `key` will not be mapped to any values, so it will not
        appear in .keySet(), .asMap(), or any other views.

        Returns
        - the values that were removed (possibly empty). The returned collection *may* be
            modifiable, but updating it will have no effect on the multimap.
        """
        ...


    def clear(self) -> None:
        """
        Removes all key-value pairs from the multimap, leaving it .isEmpty empty.
        """
        ...


    def get(self, key: "K") -> Iterable["V"]:
        """
        Returns a view collection of the values associated with `key` in this multimap, if any.
        Note that when `containsKey(key)` is False, this returns an empty collection, not `null`.
        
        Changes to the returned collection will update the underlying multimap, and vice versa.
        """
        ...


    def keySet(self) -> set["K"]:
        """
        Returns a view collection of all *distinct* keys contained in this multimap. Note that the
        key set contains a key if and only if this multimap maps that key to at least one value.
        
        Changes to the returned set will update the underlying multimap, and vice versa. However,
        *adding* to the returned set is not possible.
        """
        ...


    def keys(self) -> "Multiset"["K"]:
        """
        Returns a view collection containing the key from each key-value pair in this multimap,
        *without* collapsing duplicates. This collection has the same size as this multimap, and
        `keys().count(k) == get(k).size()` for all `k`.
        
        Changes to the returned multiset will update the underlying multimap, and vice versa.
        However, *adding* to the returned collection is not possible.
        """
        ...


    def values(self) -> Iterable["V"]:
        """
        Returns a view collection containing the *value* from each key-value pair contained in
        this multimap, without collapsing duplicates (so `values().size() == size()`).
        
        Changes to the returned collection will update the underlying multimap, and vice versa.
        However, *adding* to the returned collection is not possible.
        """
        ...


    def entries(self) -> Iterable["Entry"["K", "V"]]:
        """
        Returns a view collection of all key-value pairs contained in this multimap, as Entry
        instances.
        
        Changes to the returned collection or the entries it contains will update the underlying
        multimap, and vice versa. However, *adding* to the returned collection is not possible.
        """
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        """
        Performs the given action for all key-value pairs contained in this multimap. If an ordering is
        specified by the `Multimap` implementation, actions will be performed in the order of
        iteration of .entries(). Exceptions thrown by the action are relayed to the caller.
        
        To loop over all keys and their associated value collections, write `Multimaps.asMap(multimap).forEach((key, valueCollection) -> action())`.

        Since
        - 21.0
        """
        ...


    def asMap(self) -> dict["K", Iterable["V"]]:
        """
        Returns a view of this multimap as a `Map` from each distinct key to the nonempty
        collection of that key's associated values. Note that `this.asMap().get(k)` is equivalent
        to `this.get(k)` only when `k` is a key contained in the multimap; otherwise it
        returns `null` as opposed to an empty collection.
        
        Changes to the returned map or the collections that serve as its values will update the
        underlying multimap, and vice versa. The map does not support `put` or `putAll`,
        nor do its entries support Entry.setValue setValue.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares the specified object with this multimap for equality. Two multimaps are equal when
        their map views, as returned by .asMap, are also equal.
        
        In general, two multimaps with identical key-value mappings may or may not be equal,
        depending on the implementation. For example, two SetMultimap instances with the same
        key-value mappings are equal, but equality of two ListMultimap instances depends on the
        ordering of the values for each key.
        
        A non-empty SetMultimap cannot be equal to a non-empty ListMultimap, since
        their .asMap views contain unequal collections as values. However, any two empty
        multimaps are equal, because they both have empty .asMap views.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code for this multimap.
        
        The hash code of a multimap is defined as the hash code of the map view, as returned by
        Multimap.asMap.
        
        In general, two multimaps with identical key-value mappings may or may not have the same
        hash codes, depending on the implementation. For example, two SetMultimap instances
        with the same key-value mappings will have the same `hashCode`, but the `hashCode`
        of ListMultimap instances depends on the ordering of the values for each key.
        """
        ...



"""
Python module generated from Java source file java.util.jar.JarEntry

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.security import CodeSigner
from java.security.cert import Certificate
from java.util.jar import *
from java.util.zip import ZipEntry
from typing import Any, Callable, Iterable, Tuple


class JarEntry(ZipEntry):
    """
    This class is used to represent a JAR file entry.

    Since
    - 1.2
    """

    def __init__(self, name: str):
        """
        Creates a new `JarEntry` for the specified JAR file
        entry name.

        Arguments
        - name: the JAR file entry name

        Raises
        - NullPointerException: if the entry name is `null`
        - IllegalArgumentException: if the entry name is longer than
                   0xFFFF bytes.
        """
        ...


    def __init__(self, ze: "ZipEntry"):
        """
        Creates a new `JarEntry` with fields taken from the
        specified `ZipEntry` object.

        Arguments
        - ze: the `ZipEntry` object to create the
                  `JarEntry` from
        """
        ...


    def __init__(self, je: "JarEntry"):
        """
        Creates a new `JarEntry` with fields taken from the
        specified `JarEntry` object.

        Arguments
        - je: the `JarEntry` to copy
        """
        ...


    def getAttributes(self) -> "Attributes":
        """
        Returns the `Manifest` `Attributes` for this
        entry, or `null` if none.

        Returns
        - the `Manifest` `Attributes` for this
        entry, or `null` if none

        Raises
        - IOException: if an I/O error has occurred
        """
        ...


    def getCertificates(self) -> list["Certificate"]:
        """
        Returns the `Certificate` objects for this entry, or
        `null` if none. This method can only be called once
        the `JarEntry` has been completely verified by reading
        from the entry input stream until the end of the stream has been
        reached. Otherwise, this method will return `null`.
        
        The returned certificate array comprises all the signer certificates
        that were used to verify this entry. Each signer certificate is
        followed by its supporting certificate chain (which may be empty).
        Each signer certificate and its supporting certificate chain are ordered
        bottom-to-top (i.e., with the signer certificate first and the (root)
        certificate authority last).

        Returns
        - the `Certificate` objects for this entry, or
        `null` if none.
        """
        ...


    def getCodeSigners(self) -> list["CodeSigner"]:
        """
        Returns the `CodeSigner` objects for this entry, or
        `null` if none. This method can only be called once
        the `JarEntry` has been completely verified by reading
        from the entry input stream until the end of the stream has been
        reached. Otherwise, this method will return `null`.
        
        The returned array comprises all the code signers that have signed
        this entry.

        Returns
        - the `CodeSigner` objects for this entry, or
        `null` if none.

        Since
        - 1.5
        """
        ...


    def getRealName(self) -> str:
        """
        Returns the real name of this `JarEntry`.
        
        If this `JarEntry` is an entry of a
        <a href="JarFile.html#multirelease">multi-release jar file</a> and the
        `JarFile` is configured to be processed as such, the name returned
        by this method is the path name of the versioned entry that the
        `JarEntry` represents, rather than the path name of the base entry
        that .getName() returns. If the `JarEntry` does not represent
        a versioned entry of a multi-release `JarFile` or the `JarFile`
        is not configured for processing a multi-release jar file, this method
        returns the same name that .getName() returns.

        Returns
        - the real name of the JarEntry

        Since
        - 10
        """
        ...



"""
Python module generated from Java source file com.google.common.io.Flushables

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.io import *
from java.io import Flushable
from java.io import IOException
from typing import Any, Callable, Iterable, Tuple


class Flushables:
    """
    Utility methods for working with Flushable objects.

    Author(s)
    - Michael Lancaster

    Since
    - 1.0
    """

    @staticmethod
    def flush(flushable: "Flushable", swallowIOException: bool) -> None:
        """
        Flush a Flushable, with control over whether an `IOException` may be thrown.
        
        If `swallowIOException` is True, then we don't rethrow `IOException`, but merely
        log it.

        Arguments
        - flushable: the `Flushable` object to be flushed.
        - swallowIOException: if True, don't propagate IO exceptions thrown by the `flush`
            method

        Raises
        - IOException: if `swallowIOException` is False and Flushable.flush throws
            an `IOException`.

        See
        - Closeables.close
        """
        ...


    @staticmethod
    def flushQuietly(flushable: "Flushable") -> None:
        """
        Equivalent to calling `flush(flushable, True)`, but with no `IOException` in the
        signature.

        Arguments
        - flushable: the `Flushable` object to be flushed.
        """
        ...



"""
Python module generated from Java source file org.joml.Vector2dc

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Vector2dc:
    """
    Interface to a read-only view of a 2-dimensional vector of double-precision floats.

    Author(s)
    - Kai Burjack
    """

    def x(self) -> float:
        """
        Returns
        - the value of the x component
        """
        ...


    def y(self) -> float:
        """
        Returns
        - the value of the y component
        """
        ...


    def get(self, buffer: "ByteBuffer") -> "ByteBuffer":
        """
        Store this vector into the supplied ByteBuffer at the current
        buffer ByteBuffer.position() position.
        
        This method will not increment the position of the given ByteBuffer.
        
        In order to specify the offset into the ByteBuffer at which
        the vector is stored, use .get(int, ByteBuffer), taking
        the absolute position as parameter.

        Arguments
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer

        See
        - .get(int, ByteBuffer)
        """
        ...


    def get(self, index: int, buffer: "ByteBuffer") -> "ByteBuffer":
        """
        Store this vector into the supplied ByteBuffer starting at the specified
        absolute buffer position/index.
        
        This method will not increment the position of the given ByteBuffer.

        Arguments
        - index: the absolute position into the ByteBuffer
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer
        """
        ...


    def get(self, buffer: "DoubleBuffer") -> "DoubleBuffer":
        """
        Store this vector into the supplied DoubleBuffer at the current
        buffer DoubleBuffer.position() position.
        
        This method will not increment the position of the given DoubleBuffer.
        
        In order to specify the offset into the DoubleBuffer at which
        the vector is stored, use .get(int, DoubleBuffer), taking
        the absolute position as parameter.

        Arguments
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer

        See
        - .get(int, DoubleBuffer)
        """
        ...


    def get(self, index: int, buffer: "DoubleBuffer") -> "DoubleBuffer":
        """
        Store this vector into the supplied DoubleBuffer starting at the specified
        absolute buffer position/index.
        
        This method will not increment the position of the given DoubleBuffer.

        Arguments
        - index: the absolute position into the DoubleBuffer
        - buffer: will receive the values of this vector in `x, y` order

        Returns
        - the passed in buffer
        """
        ...


    def getToAddress(self, address: int) -> "Vector2dc":
        """
        Store this vector at the given off-heap memory address.
        
        This method will throw an UnsupportedOperationException when JOML is used with `-Djoml.nounsafe`.
        
        *This method is unsafe as it can result in a crash of the JVM process when the specified address range does not belong to this process.*

        Arguments
        - address: the off-heap address where to store this vector

        Returns
        - this
        """
        ...


    def sub(self, x: float, y: float, dest: "Vector2d") -> "Vector2d":
        """
        Subtract `(x, y)` from this vector and store the result in `dest`.

        Arguments
        - x: the x component to subtract
        - y: the y component to subtract
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def sub(self, v: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Subtract `v` from `this` vector and store the result in `dest`.

        Arguments
        - v: the vector to subtract
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def sub(self, v: "Vector2fc", dest: "Vector2d") -> "Vector2d":
        """
        Subtract `v` from `this` vector and store the result in `dest`.

        Arguments
        - v: the vector to subtract
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, scalar: float, dest: "Vector2d") -> "Vector2d":
        """
        Multiply the components of this vector by the given scalar and store the result in `dest`.

        Arguments
        - scalar: the value to multiply this vector's components by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, x: float, y: float, dest: "Vector2d") -> "Vector2d":
        """
        Multiply the components of this vector by the given scalar values and store the result in `dest`.

        Arguments
        - x: the x component to multiply this vector by
        - y: the y component to multiply this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, v: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply this vector component-wise by another vector and store the result in `dest`.

        Arguments
        - v: the vector to multiply by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def div(self, scalar: float, dest: "Vector2d") -> "Vector2d":
        """
        Divide this vector by the given scalar value and store the result in `dest`.

        Arguments
        - scalar: the scalar to divide this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def div(self, x: float, y: float, dest: "Vector2d") -> "Vector2d":
        """
        Divide the components of this vector by the given scalar values and store the result in `dest`.

        Arguments
        - x: the x component to divide this vector by
        - y: the y component to divide this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def div(self, v: "Vector2fc", dest: "Vector2d") -> "Vector2d":
        """
        Divide this vector component-wise by another vector and store the result in `dest`.

        Arguments
        - v: the vector to divide by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def div(self, v: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Divide this by `v` component-wise and store the result into `dest`.

        Arguments
        - v: the vector to divide by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, mat: "Matrix2dc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply the given matrix `mat` with `this` and store the
        result in `dest`.
        
        Note that this method performs the operation `M * this`, where `M` is the provided matrix
        and thus interprets `this` as a *column* vector.

        Arguments
        - mat: the matrix to multiply this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mul(self, mat: "Matrix2fc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply the given matrix `mat` with `this` and store the
        result in `dest`.
        
        Note that this method performs the operation `M * this`, where `M` is the provided matrix
        and thus interprets `this` as a *column* vector.

        Arguments
        - mat: the matrix to multiply this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mulTranspose(self, mat: "Matrix2dc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply the transpose of the given matrix with this vector and store the result in `dest`.
        
        Note that this method performs the operation `M^T * this`, where `M` is the provided matrix
        and thus interprets `this` as a *column* vector.

        Arguments
        - mat: the matrix
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mulTranspose(self, mat: "Matrix2fc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply the transpose of the given matrix with this vector and store the result in `dest`.
        
        Note that this method performs the operation `M^T * this`, where `M` is the provided matrix
        and thus interprets `this` as a *column* vector.

        Arguments
        - mat: the matrix
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mulPosition(self, mat: "Matrix3x2dc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply the given 3x2 matrix `mat` with `this` and store the
        result in `dest`.
        
        This method assumes the `z` component of `this` to be `1.0`.
        
        Note that this method performs the operation `M * this`, where `M` is the provided matrix
        and thus interprets `this` as a *column* vector.

        Arguments
        - mat: the matrix to multiply this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def mulDirection(self, mat: "Matrix3x2dc", dest: "Vector2d") -> "Vector2d":
        """
        Multiply the given 3x2 matrix `mat` with `this` and store the
        result in `dest`.
        
        This method assumes the `z` component of `this` to be `0.0`.
        
        Note that this method performs the operation `M * this`, where `M` is the provided matrix
        and thus interprets `this` as a *column* vector.

        Arguments
        - mat: the matrix to multiply this vector by
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def dot(self, v: "Vector2dc") -> float:
        """
        Return the dot product of this vector and `v`.

        Arguments
        - v: the other vector

        Returns
        - the dot product
        """
        ...


    def angle(self, v: "Vector2dc") -> float:
        """
        Return the angle between this vector and the supplied vector.

        Arguments
        - v: the other vector

        Returns
        - the angle, in radians
        """
        ...


    def lengthSquared(self) -> float:
        """
        Return the length squared of this vector.

        Returns
        - the length squared
        """
        ...


    def length(self) -> float:
        """
        Return the length of this vector.

        Returns
        - the length
        """
        ...


    def distance(self, v: "Vector2dc") -> float:
        """
        Return the distance between this and `v`.

        Arguments
        - v: the other vector

        Returns
        - the distance
        """
        ...


    def distanceSquared(self, v: "Vector2dc") -> float:
        """
        Return the distance squared between this and `v`.

        Arguments
        - v: the other vector

        Returns
        - the distance squared
        """
        ...


    def distance(self, v: "Vector2fc") -> float:
        """
        Return the distance between this and `v`.

        Arguments
        - v: the other vector

        Returns
        - the distance
        """
        ...


    def distanceSquared(self, v: "Vector2fc") -> float:
        """
        Return the distance squared between this and `v`.

        Arguments
        - v: the other vector

        Returns
        - the distance squared
        """
        ...


    def distance(self, x: float, y: float) -> float:
        """
        Return the distance between `this` vector and `(x, y)`.

        Arguments
        - x: the x component of the other vector
        - y: the y component of the other vector

        Returns
        - the euclidean distance
        """
        ...


    def distanceSquared(self, x: float, y: float) -> float:
        """
        Return the distance squared between `this` vector and `(x, y)`.

        Arguments
        - x: the x component of the other vector
        - y: the y component of the other vector

        Returns
        - the euclidean distance squared
        """
        ...


    def normalize(self, dest: "Vector2d") -> "Vector2d":
        """
        Normalize this vector and store the result in `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def normalize(self, length: float, dest: "Vector2d") -> "Vector2d":
        """
        Scale this vector to have the given length and store the result in `dest`.

        Arguments
        - length: the desired length
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def add(self, x: float, y: float, dest: "Vector2d") -> "Vector2d":
        """
        Add `(x, y)` to this vector and store the result in `dest`.

        Arguments
        - x: the x component to add
        - y: the y component to add
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def add(self, v: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Add `v` to this vector and store the result in `dest`.

        Arguments
        - v: the vector to add
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def add(self, v: "Vector2fc", dest: "Vector2d") -> "Vector2d":
        """
        Add `v` to this vector and store the result in `dest`.

        Arguments
        - v: the vector to add
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def negate(self, dest: "Vector2d") -> "Vector2d":
        """
        Negate this vector and store the result in `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def lerp(self, other: "Vector2dc", t: float, dest: "Vector2d") -> "Vector2d":
        """
        Linearly interpolate `this` and `other` using the given interpolation factor `t`
        and store the result in `dest`.
        
        If `t` is `0.0` then the result is `this`. If the interpolation factor is `1.0`
        then the result is `other`.

        Arguments
        - other: the other vector
        - t: the interpolation factor between 0.0 and 1.0
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def fma(self, a: "Vector2dc", b: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Add the component-wise multiplication of `a * b` to this vector
        and store the result in `dest`.

        Arguments
        - a: the first multiplicand
        - b: the second multiplicand
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def fma(self, a: float, b: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Add the component-wise multiplication of `a * b` to this vector
        and store the result in `dest`.

        Arguments
        - a: the first multiplicand
        - b: the second multiplicand
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def min(self, v: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Set the components of `dest` to be the component-wise minimum of this and the other vector.

        Arguments
        - v: the other vector
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def max(self, v: "Vector2dc", dest: "Vector2d") -> "Vector2d":
        """
        Set the components of `dest` to be the component-wise maximum of this and the other vector.

        Arguments
        - v: the other vector
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def maxComponent(self) -> int:
        """
        Determine the component with the biggest absolute value.

        Returns
        - the component index, within `[0..1]`
        """
        ...


    def minComponent(self) -> int:
        """
        Determine the component with the smallest (towards zero) absolute value.

        Returns
        - the component index, within `[0..1]`
        """
        ...


    def get(self, component: int) -> float:
        """
        Get the value of the specified component of this vector.

        Arguments
        - component: the component, within `[0..1]`

        Returns
        - the value

        Raises
        - IllegalArgumentException: if `component` is not within `[0..1]`
        """
        ...


    def get(self, mode: int, dest: "Vector2i") -> "Vector2i":
        """
        Set the components of the given vector `dest` to those of `this` vector
        using the given RoundingMode.

        Arguments
        - mode: the RoundingMode to use
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def get(self, dest: "Vector2f") -> "Vector2f":
        """
        Set the components of the given vector `dest` to those of `this` vector.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def get(self, dest: "Vector2d") -> "Vector2d":
        """
        Set the components of the given vector `dest` to those of `this` vector.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def floor(self, dest: "Vector2d") -> "Vector2d":
        """
        Compute for each component of this vector the largest (closest to positive
        infinity) `double` value that is less than or equal to that
        component and is equal to a mathematical integer and store the result in
        `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def ceil(self, dest: "Vector2d") -> "Vector2d":
        """
        Compute for each component of this vector the smallest (closest to negative
        infinity) `double` value that is greater than or equal to that
        component and is equal to a mathematical integer and store the result in
        `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def round(self, dest: "Vector2d") -> "Vector2d":
        """
        Compute for each component of this vector the closest double that is equal to
        a mathematical integer, with ties rounding to positive infinity and store
        the result in `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def isFinite(self) -> bool:
        """
        Determine whether all components are finite floating-point values, that
        is, they are not Double.isNaN() NaN and not
        Double.isInfinite() infinity.

        Returns
        - `True` if all components are finite floating-point values;
                `False` otherwise
        """
        ...


    def absolute(self, dest: "Vector2d") -> "Vector2d":
        """
        Compute the absolute of each of this vector's components
        and store the result into `dest`.

        Arguments
        - dest: will hold the result

        Returns
        - dest
        """
        ...


    def equals(self, v: "Vector2dc", delta: float) -> bool:
        """
        Compare the vector components of `this` vector with the given vector using the given `delta`
        and return whether all of them are equal within a maximum difference of `delta`.
        
        Please note that this method is not used by any data structure such as ArrayList HashSet or HashMap
        and their operations, such as ArrayList.contains(Object) or HashSet.remove(Object), since those
        data structures only use the Object.equals(Object) and Object.hashCode() methods.

        Arguments
        - v: the other vector
        - delta: the allowed maximum difference

        Returns
        - `True` whether all of the vector components are equal; `False` otherwise
        """
        ...


    def equals(self, x: float, y: float) -> bool:
        """
        Compare the vector components of `this` vector with the given `(x, y)`
        and return whether all of them are equal.

        Arguments
        - x: the x component to compare to
        - y: the y component to compare to

        Returns
        - `True` if all the vector components are equal
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.representer.Representer

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from java.util import Collections
from java.util import Iterator
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.DumperOptions import FlowStyle
from org.yaml.snakeyaml import TypeDescription
from org.yaml.snakeyaml.introspector import Property
from org.yaml.snakeyaml.introspector import PropertyUtils
from org.yaml.snakeyaml.nodes import MappingNode
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.nodes import NodeId
from org.yaml.snakeyaml.nodes import NodeTuple
from org.yaml.snakeyaml.nodes import ScalarNode
from org.yaml.snakeyaml.nodes import SequenceNode
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.representer import *
from typing import Any, Callable, Iterable, Tuple


class Representer(SafeRepresenter):
    """
    Represent JavaBeans
    """

    def __init__(self, options: "DumperOptions"):
        ...


    def addTypeDescription(self, td: "TypeDescription") -> "TypeDescription":
        ...


    def setPropertyUtils(self, propertyUtils: "PropertyUtils") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityUnleashEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import Entity
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityUnleashEvent(EntityEvent):
    """
    Called immediately prior to an entity being unleashed.
    """

    def __init__(self, entity: "Entity", reason: "UnleashReason"):
        ...


    def getReason(self) -> "UnleashReason":
        """
        Returns the reason for the unleashing.

        Returns
        - The reason
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class UnleashReason(Enum):

        HOLDER_GONE = 0
        """
        When the entity's leashholder has died or logged out, and so is
        unleashed
        """
        PLAYER_UNLEASH = 1
        """
        When the entity's leashholder attempts to unleash it
        """
        DISTANCE = 2
        """
        When the entity's leashholder is more than 10 blocks away
        """
        UNKNOWN = 3



"""
Python module generated from Java source file com.google.common.eventbus.SubscriberExceptionHandler

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.eventbus import *
from typing import Any, Callable, Iterable, Tuple


class SubscriberExceptionHandler:
    """
    Handler for exceptions thrown by event subscribers.

    Since
    - 16.0
    """

    def handleException(self, exception: "Throwable", context: "SubscriberExceptionContext") -> None:
        """
        Handles exceptions thrown by subscribers.
        """
        ...



"""
Python module generated from Java source file java.util.function.Supplier

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class Supplier:
    """
    Represents a supplier of results.
    
    There is no requirement that a new or distinct result be returned each
    time the supplier is invoked.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .get().
    
    Type `<T>`: the type of results supplied by this supplier

    Since
    - 1.8
    """

    def get(self) -> "T":
        """
        Gets a result.

        Returns
        - a result
        """
        ...



"""
Python module generated from Java source file org.bukkit.map.MapPalette

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.map import *
from typing import Any, Callable, Iterable, Tuple


class MapPalette:
    """
    Represents the palette that map items use.
    
    These fields are hee base color ranges. Each entry corresponds to four
    colors of varying shades with values entry to entry + 3.
    """

    TRANSPARENT = 0
    """
    Deprecated
    - Magic value
    """
    LIGHT_GREEN = 4
    """
    Deprecated
    - Magic value
    """
    LIGHT_BROWN = 8
    """
    Deprecated
    - Magic value
    """
    GRAY_1 = 12
    """
    Deprecated
    - Magic value
    """
    RED = 16
    """
    Deprecated
    - Magic value
    """
    PALE_BLUE = 20
    """
    Deprecated
    - Magic value
    """
    GRAY_2 = 24
    """
    Deprecated
    - Magic value
    """
    DARK_GREEN = 28
    """
    Deprecated
    - Magic value
    """
    WHITE = 32
    """
    Deprecated
    - Magic value
    """
    LIGHT_GRAY = 36
    """
    Deprecated
    - Magic value
    """
    BROWN = 40
    """
    Deprecated
    - Magic value
    """
    DARK_GRAY = 44
    """
    Deprecated
    - Magic value
    """
    BLUE = 48
    """
    Deprecated
    - Magic value
    """
    DARK_BROWN = 52
    """
    Deprecated
    - Magic value
    """


    @staticmethod
    def resizeImage(image: "Image") -> "BufferedImage":
        """
        Resize an image to 128x128.

        Arguments
        - image: The image to resize.

        Returns
        - The resized image.
        """
        ...


    @staticmethod
    def imageToBytes(image: "Image") -> list[int]:
        """
        Convert an Image to a byte[] using the palette.

        Arguments
        - image: The image to convert.

        Returns
        - A byte[] containing the pixels of the image.

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def matchColor(r: int, g: int, b: int) -> int:
        """
        Get the index of the closest matching color in the palette to the given
        color.

        Arguments
        - r: The red component of the color.
        - b: The blue component of the color.
        - g: The green component of the color.

        Returns
        - The index in the palette.

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def matchColor(color: "Color") -> int:
        """
        Get the index of the closest matching color in the palette to the given
        color.

        Arguments
        - color: The Color to match.

        Returns
        - The index in the palette.

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getColor(index: int) -> "Color":
        """
        Get the value of the given color in the palette.

        Arguments
        - index: The index in the palette.

        Returns
        - The Color of the palette entry.

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def setMapColorCache(mapColorCache: "MapColorCache") -> None:
        """
        Sets the given MapColorCache.

        Arguments
        - mapColorCache: The map color cache to set
        """
        ...


    class MapColorCache:
        """
        Holds cached information for matching map colors of a given RBG color.
        """

        def isCached(self) -> bool:
            """
            Returns True if the MapColorCache has values cached, if not it will
            return False.
            A case where it might return False is when the cache is not build jet.

            Returns
            - True if this MapColorCache has values cached otherwise False
            """
            ...


        def matchColor(self, color: "Color") -> int:
            """
            Get the cached index of the closest matching color in the palette to the given
            color.

            Arguments
            - color: The Color to match.

            Returns
            - The index in the palette.

            Raises
            - IllegalStateException: if .isCached() returns False

            Deprecated
            - Magic value
            """
            ...



"""
Python module generated from Java source file org.bukkit.potion.PotionType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.base import Suppliers
from enum import Enum
from java.util.function import Supplier
from org.bukkit import Bukkit
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit.potion import *
from org.bukkit.registry import RegistryAware
from typing import Any, Callable, Iterable, Tuple


class PotionType(Enum):
    """
    This enum reflects and matches each potion state that can be obtained from
    the Creative mode inventory
    """

    WATER = ("water")
    MUNDANE = ("mundane")
    THICK = ("thick")
    AWKWARD = ("awkward")
    NIGHT_VISION = ("night_vision")
    LONG_NIGHT_VISION = ("long_night_vision")
    INVISIBILITY = ("invisibility")
    LONG_INVISIBILITY = ("long_invisibility")
    LEAPING = ("leaping")
    LONG_LEAPING = ("long_leaping")
    STRONG_LEAPING = ("strong_leaping")
    FIRE_RESISTANCE = ("fire_resistance")
    LONG_FIRE_RESISTANCE = ("long_fire_resistance")
    SWIFTNESS = ("swiftness")
    LONG_SWIFTNESS = ("long_swiftness")
    STRONG_SWIFTNESS = ("strong_swiftness")
    SLOWNESS = ("slowness")
    LONG_SLOWNESS = ("long_slowness")
    STRONG_SLOWNESS = ("strong_slowness")
    WATER_BREATHING = ("water_breathing")
    LONG_WATER_BREATHING = ("long_water_breathing")
    HEALING = ("healing")
    STRONG_HEALING = ("strong_healing")
    HARMING = ("harming")
    STRONG_HARMING = ("strong_harming")
    POISON = ("poison")
    LONG_POISON = ("long_poison")
    STRONG_POISON = ("strong_poison")
    REGENERATION = ("regeneration")
    LONG_REGENERATION = ("long_regeneration")
    STRONG_REGENERATION = ("strong_regeneration")
    STRENGTH = ("strength")
    LONG_STRENGTH = ("long_strength")
    STRONG_STRENGTH = ("strong_strength")
    WEAKNESS = ("weakness")
    LONG_WEAKNESS = ("long_weakness")
    LUCK = ("luck")
    TURTLE_MASTER = ("turtle_master")
    LONG_TURTLE_MASTER = ("long_turtle_master")
    STRONG_TURTLE_MASTER = ("strong_turtle_master")
    SLOW_FALLING = ("slow_falling")
    LONG_SLOW_FALLING = ("long_slow_falling")
    WIND_CHARGED = ("wind_charged")
    WEAVING = ("weaving")
    OOZING = ("oozing")
    INFESTED = ("infested")


    def getEffectType(self) -> "PotionEffectType":
        """
        Returns
        - the potion effect type of this potion type

        Deprecated
        - Potions can have multiple effects use .getPotionEffects()
        """
        ...


    def getPotionEffects(self) -> list["PotionEffect"]:
        """
        Returns
        - a list of all effects this potion type has
        """
        ...


    def isInstant(self) -> bool:
        """
        Returns
        - if this potion type is instant

        Deprecated
        - PotionType can have multiple effects, some of which can be instant and others not.
        Use PotionEffectType.isInstant() in combination with .getPotionEffects() and PotionEffect.getType()
        """
        ...


    def isUpgradeable(self) -> bool:
        """
        Checks if the potion type has an upgraded state.
        This refers to whether or not the potion type can be Tier 2,
        such as Potion of Fire Resistance II.

        Returns
        - True if the potion type can be upgraded;
        """
        ...


    def isExtendable(self) -> bool:
        """
        Checks if the potion type has an extended state.
        This refers to the extended duration potions

        Returns
        - True if the potion type can be extended
        """
        ...


    def getMaxLevel(self) -> int:
        ...


    def getKeyOrThrow(self) -> "NamespacedKey":
        ...


    def getKeyOrNull(self) -> "NamespacedKey":
        ...


    def isRegistered(self) -> bool:
        ...


    @staticmethod
    def getByEffect(effectType: "PotionEffectType") -> "PotionType":
        """
        Arguments
        - effectType: the effect to get by

        Returns
        - the matching potion type

        Deprecated
        - Misleading
        """
        ...


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...


    class InternalPotionData:
        """
        Deprecated
        - Do not use, interface will get removed, and the plugin won't run
        """

        def getEffectType(self) -> "PotionEffectType":
            ...


        def getPotionEffects(self) -> list["PotionEffect"]:
            ...


        def isInstant(self) -> bool:
            ...


        def isUpgradeable(self) -> bool:
            ...


        def isExtendable(self) -> bool:
            ...


        def getMaxLevel(self) -> int:
            ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Bamboo

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import Ageable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Bamboo(Ageable, Sapling):
    """
    'leaves' represents the size of the leaves on this bamboo block.
    """

    def getLeaves(self) -> "Leaves":
        """
        Gets the value of the 'leaves' property.

        Returns
        - the 'leaves' value
        """
        ...


    def setLeaves(self, leaves: "Leaves") -> None:
        """
        Sets the value of the 'leaves' property.

        Arguments
        - leaves: the new 'leaves' value
        """
        ...


    class Leaves(Enum):
        """
        Bamboo leaf size.
        """

        NONE = 0
        """
        No leaves.
        """
        SMALL = 1
        """
        Small leaves.
        """
        LARGE = 2
        """
        Large leaves.
        """



"""
Python module generated from Java source file org.bukkit.block.data.type.Bell

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import Directional
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Bell(Directional, Powerable):
    """
    'attachment' denotes how the bell is attached to its block.
    """

    def getAttachment(self) -> "Attachment":
        """
        Gets the value of the 'attachment' property.

        Returns
        - the 'attachment' value
        """
        ...


    def setAttachment(self, attachment: "Attachment") -> None:
        """
        Sets the value of the 'attachment' property.

        Arguments
        - attachment: the new 'attachment' value
        """
        ...


    class Attachment(Enum):
        """
        What the bell is attached to.
        """

        FLOOR = 0
        """
        Placed on floor.
        """
        CEILING = 1
        """
        Placed on ceiling.
        """
        SINGLE_WALL = 2
        """
        Placed on one wall.
        """
        DOUBLE_WALL = 3
        """
        Placed between two walls.
        """



"""
Python module generated from Java source file org.bukkit.event.server.ServerListPingEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.net import InetAddress
from java.util import Iterator
from org.bukkit import Bukkit
from org.bukkit import UndefinedNullability
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.server import *
from org.bukkit.util import CachedServerIcon
from typing import Any, Callable, Iterable, Tuple


class ServerListPingEvent(ServerEvent, Iterable):
    """
    Called when a server list ping is coming in. Displayed players can be
    checked and removed by .iterator() iterating over this event.
    
    **Note:** The players in .iterator() will not be shown in the
    server info if Bukkit.getHideOnlinePlayers() is True.
    """

    def __init__(self, hostname: str, address: "InetAddress", motd: str, numPlayers: int, maxPlayers: int):
        ...


    def getHostname(self) -> str:
        """
        Gets the hostname that the player used to connect to the server, or
        blank if unknown

        Returns
        - The hostname
        """
        ...


    def getAddress(self) -> "InetAddress":
        """
        Get the address the ping is coming from.

        Returns
        - the address
        """
        ...


    def getMotd(self) -> str:
        """
        Get the message of the day message.

        Returns
        - the message of the day
        """
        ...


    def setMotd(self, motd: str) -> None:
        """
        Change the message of the day message.

        Arguments
        - motd: the message of the day
        """
        ...


    def getNumPlayers(self) -> int:
        """
        Get the number of players sent.

        Returns
        - the number of players
        """
        ...


    def getMaxPlayers(self) -> int:
        """
        Get the maximum number of players sent.

        Returns
        - the maximum number of players
        """
        ...


    def shouldSendChatPreviews(self) -> bool:
        """
        Gets whether the server needs to send a preview of the chat to the
        client.

        Returns
        - True if chat preview is enabled, False otherwise

        Deprecated
        - chat previews have been removed
        """
        ...


    def setMaxPlayers(self, maxPlayers: int) -> None:
        """
        Set the maximum number of players sent.

        Arguments
        - maxPlayers: the maximum number of player
        """
        ...


    def setServerIcon(self, icon: "CachedServerIcon") -> None:
        """
        Sets the server-icon sent to the client.

        Arguments
        - icon: the icon to send to the client

        Raises
        - IllegalArgumentException: if the CachedServerIcon is not
            created by the caller of this event; null may be accepted for some
            implementations
        - UnsupportedOperationException: if the caller of this event does
            not support setting the server icon
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    def iterator(self) -> Iterator["Player"]:
        """
        
        
        Calling the Iterator.remove() method will force that particular
        player to not be displayed on the player list, decrease the size
        returned by .getNumPlayers(), and will not be returned again by
        any new iterator.
        
        **Note:** The players here will not be shown in the server info if
        Bukkit.getHideOnlinePlayers() is True.

        Raises
        - UnsupportedOperationException: if the caller of this event does
            not support removing players
        """
        ...



"""
Python module generated from Java source file java.util.SortedSet

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class SortedSet(Set):

    def comparator(self) -> "Comparator"["E"]:
        """
        Returns the comparator used to order the elements in this set,
        or `null` if this set uses the Comparable
        natural ordering of its elements.

        Returns
        - the comparator used to order the elements in this set,
                or `null` if this set uses the natural ordering
                of its elements
        """
        ...


    def subSet(self, fromElement: "E", toElement: "E") -> "SortedSet"["E"]:
        """
        Returns a view of the portion of this set whose elements range
        from `fromElement`, inclusive, to `toElement`,
        exclusive.  (If `fromElement` and `toElement` are
        equal, the returned set is empty.)  The returned set is backed
        by this set, so changes in the returned set are reflected in
        this set, and vice-versa.  The returned set supports all
        optional set operations that this set supports.
        
        The returned set will throw an `IllegalArgumentException`
        on an attempt to insert an element outside its range.

        Arguments
        - fromElement: low endpoint (inclusive) of the returned set
        - toElement: high endpoint (exclusive) of the returned set

        Returns
        - a view of the portion of this set whose elements range from
                `fromElement`, inclusive, to `toElement`, exclusive

        Raises
        - ClassCastException: if `fromElement` and
                `toElement` cannot be compared to one another using this
                set's comparator (or, if the set has no comparator, using
                natural ordering).  Implementations may, but are not required
                to, throw this exception if `fromElement` or
                `toElement` cannot be compared to elements currently in
                the set.
        - NullPointerException: if `fromElement` or
                `toElement` is null and this set does not permit null
                elements
        - IllegalArgumentException: if `fromElement` is
                greater than `toElement`; or if this set itself
                has a restricted range, and `fromElement` or
                `toElement` lies outside the bounds of the range
        """
        ...


    def headSet(self, toElement: "E") -> "SortedSet"["E"]:
        """
        Returns a view of the portion of this set whose elements are
        strictly less than `toElement`.  The returned set is
        backed by this set, so changes in the returned set are
        reflected in this set, and vice-versa.  The returned set
        supports all optional set operations that this set supports.
        
        The returned set will throw an `IllegalArgumentException`
        on an attempt to insert an element outside its range.

        Arguments
        - toElement: high endpoint (exclusive) of the returned set

        Returns
        - a view of the portion of this set whose elements are strictly
                less than `toElement`

        Raises
        - ClassCastException: if `toElement` is not compatible
                with this set's comparator (or, if the set has no comparator,
                if `toElement` does not implement Comparable).
                Implementations may, but are not required to, throw this
                exception if `toElement` cannot be compared to elements
                currently in the set.
        - NullPointerException: if `toElement` is null and
                this set does not permit null elements
        - IllegalArgumentException: if this set itself has a
                restricted range, and `toElement` lies outside the
                bounds of the range
        """
        ...


    def tailSet(self, fromElement: "E") -> "SortedSet"["E"]:
        """
        Returns a view of the portion of this set whose elements are
        greater than or equal to `fromElement`.  The returned
        set is backed by this set, so changes in the returned set are
        reflected in this set, and vice-versa.  The returned set
        supports all optional set operations that this set supports.
        
        The returned set will throw an `IllegalArgumentException`
        on an attempt to insert an element outside its range.

        Arguments
        - fromElement: low endpoint (inclusive) of the returned set

        Returns
        - a view of the portion of this set whose elements are greater
                than or equal to `fromElement`

        Raises
        - ClassCastException: if `fromElement` is not compatible
                with this set's comparator (or, if the set has no comparator,
                if `fromElement` does not implement Comparable).
                Implementations may, but are not required to, throw this
                exception if `fromElement` cannot be compared to elements
                currently in the set.
        - NullPointerException: if `fromElement` is null
                and this set does not permit null elements
        - IllegalArgumentException: if this set itself has a
                restricted range, and `fromElement` lies outside the
                bounds of the range
        """
        ...


    def first(self) -> "E":
        """
        Returns the first (lowest) element currently in this set.

        Returns
        - the first (lowest) element currently in this set

        Raises
        - NoSuchElementException: if this set is empty
        """
        ...


    def last(self) -> "E":
        """
        Returns the last (highest) element currently in this set.

        Returns
        - the last (highest) element currently in this set

        Raises
        - NoSuchElementException: if this set is empty
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Creates a `Spliterator` over the elements in this sorted set.
        
        The `Spliterator` reports Spliterator.DISTINCT,
        Spliterator.SORTED and Spliterator.ORDERED.
        Implementations should document the reporting of additional
        characteristic values.
        
        The spliterator's comparator (see
        java.util.Spliterator.getComparator()) must be `null` if
        the sorted set's comparator (see .comparator()) is `null`.
        Otherwise, the spliterator's comparator must be the same as or impose the
        same total ordering as the sorted set's comparator.

        Returns
        - a `Spliterator` over the elements in this sorted set

        Since
        - 1.8

        Unknown Tags
        - The default implementation creates a
        *<a href="Spliterator.html#binding">late-binding</a>* spliterator
        from the sorted set's `Iterator`.  The spliterator inherits the
        *fail-fast* properties of the set's iterator.  The
        spliterator's comparator is the same as the sorted set's comparator.
        
        The created `Spliterator` additionally reports
        Spliterator.SIZED.
        - The created `Spliterator` additionally reports
        Spliterator.SUBSIZED.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.inventory.InventoryDragEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import ImmutableSet
from java.util import Collections
from org.bukkit import Location
from org.bukkit.entity import HumanEntity
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.inventory import *
from org.bukkit.inventory import Inventory
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory import ItemStack
from org.bukkit.plugin import Plugin
from org.bukkit.scheduler import BukkitScheduler
from typing import Any, Callable, Iterable, Tuple


class InventoryDragEvent(InventoryInteractEvent):
    """
    This event is called when the player drags an item in their cursor across
    the inventory. The ItemStack is distributed across the slots the
    HumanEntity dragged over. The method of distribution is described by the
    DragType returned by .getType().
    
    Canceling this event will result in none of the changes described in
    .getNewItems() being applied to the Inventory.
    
    Because InventoryDragEvent occurs within a modification of the Inventory,
    not all Inventory related methods are safe to use.
    
    The following should never be invoked by an EventHandler for
    InventoryDragEvent using the HumanEntity or InventoryView associated with
    this event.
    
    - HumanEntity.closeInventory()
    - HumanEntity.openInventory(Inventory)
    - HumanEntity.openWorkbench(Location, boolean)
    - HumanEntity.openEnchanting(Location, boolean)
    - InventoryView.close()
    
    To invoke one of these methods, schedule a task using
    BukkitScheduler.runTask(Plugin, Runnable), which will run the task
    on the next tick.  Also be aware that this is not an exhaustive list, and
    other methods could potentially create issues as well.
    
    Assuming the EntityHuman associated with this event is an instance of a
    Player, manipulating the MaxStackSize or contents of an Inventory will
    require an Invocation of Player.updateInventory().
    
    Any modifications to slots that are modified by the results of this
    InventoryDragEvent will be overwritten. To change these slots, this event
    should be cancelled and the changes applied. Alternatively, scheduling a
    task using BukkitScheduler.runTask(Plugin, Runnable), which would
    execute the task on the next tick, would work as well.
    """

    def __init__(self, what: "InventoryView", newCursor: "ItemStack", oldCursor: "ItemStack", right: bool, slots: dict["Integer", "ItemStack"]):
        ...


    def getNewItems(self) -> dict["Integer", "ItemStack"]:
        """
        Gets all items to be added to the inventory in this drag.

        Returns
        - map from raw slot id to new ItemStack
        """
        ...


    def getRawSlots(self) -> set["Integer"]:
        """
        Gets the raw slot ids to be changed in this drag.

        Returns
        - list of raw slot ids, suitable for getView().getItem(int)
        """
        ...


    def getInventorySlots(self) -> set["Integer"]:
        """
        Gets the slots to be changed in this drag.

        Returns
        - list of converted slot ids, suitable for org.bukkit.inventory.Inventory.getItem(int).
        """
        ...


    def getCursor(self) -> "ItemStack":
        """
        Gets the result cursor after the drag is done. The returned value is
        mutable.

        Returns
        - the result cursor
        """
        ...


    def setCursor(self, newCursor: "ItemStack") -> None:
        """
        Sets the result cursor after the drag is done.
        
        Changing this item stack changes the cursor item. Note that changing
        the affected "dragged" slots does not change this ItemStack, nor does
        changing this ItemStack affect the "dragged" slots.

        Arguments
        - newCursor: the new cursor ItemStack
        """
        ...


    def getOldCursor(self) -> "ItemStack":
        """
        Gets an ItemStack representing the cursor prior to any modifications
        as a result of this drag.

        Returns
        - the original cursor
        """
        ...


    def getType(self) -> "DragType":
        """
        Gets the DragType that describes the behavior of ItemStacks placed
        after this InventoryDragEvent.
        
        The ItemStacks and the raw slots that they're being applied to can be
        found using .getNewItems().

        Returns
        - the DragType of this InventoryDragEvent
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.graph.InvalidatableSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Supplier
from com.google.common.collect import ForwardingSet
from com.google.common.graph import *
from typing import Any, Callable, Iterable, Tuple


class InvalidatableSet(ForwardingSet):
    """
    A subclass of `ForwardingSet` that throws `IllegalStateException` on invocation of any method
    (except `hashCode` and `equals`) if the provided `Supplier` returns False.
    """

    @staticmethod
    def of(delegate: set["E"], validator: "Supplier"["Boolean"], errorMessage: "Supplier"[str]) -> "InvalidatableSet"["E"]:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file com.google.common.hash.BloomFilter

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import Objects
from com.google.common.base import Predicate
from com.google.common.hash import *
from com.google.common.hash.BloomFilterStrategies import LockFreeBitArray
from com.google.common.math import DoubleMath
from com.google.common.math import LongMath
from com.google.common.primitives import SignedBytes
from com.google.common.primitives import UnsignedBytes
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.io import DataInputStream
from java.io import DataOutputStream
from java.io import IOException
from java.io import InputStream
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io import OutputStream
from java.io import Serializable
from java.math import RoundingMode
from java.util.stream import Collector
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class BloomFilter(Predicate, Serializable):
    """
    A Bloom filter for instances of `T`. A Bloom filter offers an approximate containment test
    with one-sided error: if it claims that an element is contained in it, this might be in error,
    but if it claims that an element is *not* contained in it, then this is definitely True.
    
    If you are unfamiliar with Bloom filters, this nice <a
    href="http://llimllib.github.io/bloomfilter-tutorial/">tutorial</a> may help you understand how
    they work.
    
    The False positive probability (`FPP`) of a Bloom filter is defined as the probability
    that .mightContain(Object) will erroneously return `True` for an object that
    has not actually been put in the `BloomFilter`.
    
    Bloom filters are serializable. They also support a more compact serial representation via the
    .writeTo and .readFrom methods. Both serialized forms will continue to be
    supported by future versions of this library. However, serial forms generated by newer versions
    of the code may not be readable by older versions of the code (e.g., a serialized Bloom filter
    generated today may *not* be readable by a binary that was compiled 6 months ago).
    
    As of Guava 23.0, this class is thread-safe and lock-free. It internally uses atomics and
    compare-and-swap to ensure correctness when multiple threads are used to access it.
    
    Type `<T>`: the type of instances that the `BloomFilter` accepts

    Author(s)
    - Kevin Bourrillion

    Since
    - 11.0 (thread-safe since 23.0)
    """

    def copy(self) -> "BloomFilter"["T"]:
        """
        Creates a new `BloomFilter` that's a copy of this instance. The new instance is equal to
        this instance but shares no mutable state.

        Since
        - 12.0
        """
        ...


    def mightContain(self, object: "T") -> bool:
        """
        Returns `True` if the element *might* have been put in this Bloom filter, `False` if this is *definitely* not the case.
        """
        ...


    def apply(self, input: "T") -> bool:
        """
        Deprecated
        - Provided only to satisfy the Predicate interface; use .mightContain
            instead.
        """
        ...


    def put(self, object: "T") -> bool:
        """
        Puts an element into this `BloomFilter`. Ensures that subsequent invocations of .mightContain(Object) with the same element will always return `True`.

        Returns
        - True if the Bloom filter's bits changed as a result of this operation. If the bits
            changed, this is *definitely* the first time `object` has been added to the
            filter. If the bits haven't changed, this *might* be the first time `object` has
            been added to the filter. Note that `put(t)` always returns the *opposite*
            result to what `mightContain(t)` would have returned at the time it is called.

        Since
        - 12.0 (present in 11.0 with `void` return type})
        """
        ...


    def expectedFpp(self) -> float:
        """
        Returns the probability that .mightContain(Object) will erroneously return `True` for an object that has not actually been put in the `BloomFilter`.
        
        Ideally, this number should be close to the `fpp` parameter passed in .create(Funnel, int, double), or smaller. If it is significantly higher, it is usually the
        case that too many elements (more than expected) have been put in the `BloomFilter`,
        degenerating it.

        Since
        - 14.0 (since 11.0 as expectedFalsePositiveProbability())
        """
        ...


    def approximateElementCount(self) -> int:
        """
        Returns an estimate for the total number of distinct elements that have been added to this
        Bloom filter. This approximation is reasonably accurate if it does not exceed the value of
        `expectedInsertions` that was used when constructing the filter.

        Since
        - 22.0
        """
        ...


    def isCompatible(self, that: "BloomFilter"["T"]) -> bool:
        """
        Determines whether a given Bloom filter is compatible with this Bloom filter. For two Bloom
        filters to be compatible, they must:
        
        
          - not be the same instance
          - have the same number of hash functions
          - have the same bit size
          - have the same strategy
          - have equal funnels

        Arguments
        - that: The Bloom filter to check for compatibility.

        Since
        - 15.0
        """
        ...


    def putAll(self, that: "BloomFilter"["T"]) -> None:
        """
        Combines this Bloom filter with another Bloom filter by performing a bitwise OR of the
        underlying data. The mutations happen to **this** instance. Callers must ensure the Bloom
        filters are appropriately sized to avoid saturating them.

        Arguments
        - that: The Bloom filter to combine this Bloom filter with. It is not mutated.

        Raises
        - IllegalArgumentException: if `isCompatible(that) == False`

        Since
        - 15.0
        """
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...


    @staticmethod
    def toBloomFilter(funnel: "Funnel"["T"], expectedInsertions: int) -> "Collector"["T", Any, "BloomFilter"["T"]]:
        """
        Returns a `Collector` expecting the specified number of insertions, and yielding a BloomFilter with False positive probability 3%.
        
        Note that if the `Collector` receives significantly more elements than specified, the
        resulting `BloomFilter` will suffer a sharp deterioration of its False positive
        probability.
        
        The constructed `BloomFilter` will be serializable if the provided `Funnel<T>`
        is.
        
        It is recommended that the funnel be implemented as a Java enum. This has the benefit of
        ensuring proper serialization and deserialization, which is important since .equals
        also relies on object identity of funnels.

        Arguments
        - funnel: the funnel of T's that the constructed `BloomFilter` will use
        - expectedInsertions: the number of expected insertions to the constructed `BloomFilter`; must be positive

        Returns
        - a `Collector` generating a `BloomFilter` of the received elements

        Since
        - 23.0
        """
        ...


    @staticmethod
    def toBloomFilter(funnel: "Funnel"["T"], expectedInsertions: int, fpp: float) -> "Collector"["T", Any, "BloomFilter"["T"]]:
        """
        Returns a `Collector` expecting the specified number of insertions, and yielding a BloomFilter with the specified expected False positive probability.
        
        Note that if the `Collector` receives significantly more elements than specified, the
        resulting `BloomFilter` will suffer a sharp deterioration of its False positive
        probability.
        
        The constructed `BloomFilter` will be serializable if the provided `Funnel<T>`
        is.
        
        It is recommended that the funnel be implemented as a Java enum. This has the benefit of
        ensuring proper serialization and deserialization, which is important since .equals
        also relies on object identity of funnels.

        Arguments
        - funnel: the funnel of T's that the constructed `BloomFilter` will use
        - expectedInsertions: the number of expected insertions to the constructed `BloomFilter`; must be positive
        - fpp: the desired False positive probability (must be positive and less than 1.0)

        Returns
        - a `Collector` generating a `BloomFilter` of the received elements

        Since
        - 23.0
        """
        ...


    @staticmethod
    def create(funnel: "Funnel"["T"], expectedInsertions: int, fpp: float) -> "BloomFilter"["T"]:
        """
        Creates a BloomFilter with the expected number of insertions and expected False
        positive probability.
        
        Note that overflowing a `BloomFilter` with significantly more elements than specified,
        will result in its saturation, and a sharp deterioration of its False positive probability.
        
        The constructed `BloomFilter` will be serializable if the provided `Funnel<T>`
        is.
        
        It is recommended that the funnel be implemented as a Java enum. This has the benefit of
        ensuring proper serialization and deserialization, which is important since .equals
        also relies on object identity of funnels.

        Arguments
        - funnel: the funnel of T's that the constructed `BloomFilter` will use
        - expectedInsertions: the number of expected insertions to the constructed `BloomFilter`; must be positive
        - fpp: the desired False positive probability (must be positive and less than 1.0)

        Returns
        - a `BloomFilter`
        """
        ...


    @staticmethod
    def create(funnel: "Funnel"["T"], expectedInsertions: int, fpp: float) -> "BloomFilter"["T"]:
        """
        Creates a BloomFilter with the expected number of insertions and expected False
        positive probability.
        
        Note that overflowing a `BloomFilter` with significantly more elements than specified,
        will result in its saturation, and a sharp deterioration of its False positive probability.
        
        The constructed `BloomFilter` will be serializable if the provided `Funnel<T>`
        is.
        
        It is recommended that the funnel be implemented as a Java enum. This has the benefit of
        ensuring proper serialization and deserialization, which is important since .equals
        also relies on object identity of funnels.

        Arguments
        - funnel: the funnel of T's that the constructed `BloomFilter` will use
        - expectedInsertions: the number of expected insertions to the constructed `BloomFilter`; must be positive
        - fpp: the desired False positive probability (must be positive and less than 1.0)

        Returns
        - a `BloomFilter`

        Since
        - 19.0
        """
        ...


    @staticmethod
    def create(funnel: "Funnel"["T"], expectedInsertions: int) -> "BloomFilter"["T"]:
        """
        Creates a BloomFilter with the expected number of insertions and a default expected
        False positive probability of 3%.
        
        Note that overflowing a `BloomFilter` with significantly more elements than specified,
        will result in its saturation, and a sharp deterioration of its False positive probability.
        
        The constructed `BloomFilter` will be serializable if the provided `Funnel<T>`
        is.
        
        It is recommended that the funnel be implemented as a Java enum. This has the benefit of
        ensuring proper serialization and deserialization, which is important since .equals
        also relies on object identity of funnels.

        Arguments
        - funnel: the funnel of T's that the constructed `BloomFilter` will use
        - expectedInsertions: the number of expected insertions to the constructed `BloomFilter`; must be positive

        Returns
        - a `BloomFilter`
        """
        ...


    @staticmethod
    def create(funnel: "Funnel"["T"], expectedInsertions: int) -> "BloomFilter"["T"]:
        """
        Creates a BloomFilter with the expected number of insertions and a default expected
        False positive probability of 3%.
        
        Note that overflowing a `BloomFilter` with significantly more elements than specified,
        will result in its saturation, and a sharp deterioration of its False positive probability.
        
        The constructed `BloomFilter` will be serializable if the provided `Funnel<T>`
        is.
        
        It is recommended that the funnel be implemented as a Java enum. This has the benefit of
        ensuring proper serialization and deserialization, which is important since .equals
        also relies on object identity of funnels.

        Arguments
        - funnel: the funnel of T's that the constructed `BloomFilter` will use
        - expectedInsertions: the number of expected insertions to the constructed `BloomFilter`; must be positive

        Returns
        - a `BloomFilter`

        Since
        - 19.0
        """
        ...


    def writeTo(self, out: "OutputStream") -> None:
        """
        Writes this `BloomFilter` to an output stream, with a custom format (not Java
        serialization). This has been measured to save at least 400 bytes compared to regular
        serialization.
        
        Use .readFrom(InputStream, Funnel) to reconstruct the written BloomFilter.
        """
        ...


    @staticmethod
    def readFrom(in: "InputStream", funnel: "Funnel"["T"]) -> "BloomFilter"["T"]:
        """
        Reads a byte stream, which was written by .writeTo(OutputStream), into a `BloomFilter`.
        
        The `Funnel` to be used is not encoded in the stream, so it must be provided here.
        **Warning:** the funnel provided **must** behave identically to the one used to populate
        the original Bloom filter!

        Raises
        - IOException: if the InputStream throws an `IOException`, or if its data does not
            appear to be a BloomFilter serialized using the .writeTo(OutputStream) method.
        """
        ...



"""
Python module generated from Java source file com.google.common.base.Verify

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Verify:
    """
    Static convenience methods that serve the same purpose as Java language <a
    href="https://docs.oracle.com/javase/8/docs/technotes/guides/language/assert.html">assertions</a>,
    except that they are always enabled. These methods should be used instead of Java assertions
    whenever there is a chance the check may fail "in real life". Example:
    
    ````Bill bill = remoteService.getLastUnpaidBill();
    
    // In case bug 12345 happens again we'd rather just die
    Verify.verify(bill.status() == Status.UNPAID,
        "Unexpected bill status: %s", bill.status());````
    
    <h3>Comparison to alternatives</h3>
    
    **Note:** In some cases the differences explained below can be subtle. When it's unclear
    which approach to use, **don't worry** too much about it; just pick something that seems
    reasonable and it will be fine.
    
    
      - If checking whether the *caller* has violated your method or constructor's contract
          (such as by passing an invalid argument), use the utilities of the Preconditions
          class instead.
      - If checking an *impossible* condition (which *cannot* happen unless your own
          class or its *trusted* dependencies is badly broken), this is what ordinary Java
          assertions are for. Note that assertions are not enabled by default; they are essentially
          considered "compiled comments."
      - An explicit `if/throw` (as illustrated below) is always acceptable; we still
          recommend using our VerifyException exception type. Throwing a plain RuntimeException is frowned upon.
      - Use of java.util.Objects.requireNonNull(Object) is generally discouraged, since
          .verifyNotNull(Object) and Preconditions.checkNotNull(Object) perform the
          same function with more clarity.
    
    
    <h3>Warning about performance</h3>
    
    Remember that parameter values for message construction must all be computed eagerly, and
    autoboxing and varargs array creation may happen as well, even when the verification succeeds and
    the message ends up unneeded. Performance-sensitive verification checks should continue to use
    usual form:
    
    ````Bill bill = remoteService.getLastUnpaidBill();
    if (bill.status() != Status.UNPAID) {
      throw new VerifyException("Unexpected bill status: " + bill.status());`
    }```
    
    <h3>Only `%s` is supported</h3>
    
    As with Preconditions, `Verify` uses Strings.lenientFormat to format
    error message template strings. This only supports the `"%s"` specifier, not the full range
    of java.util.Formatter specifiers. However, note that if the number of arguments does not
    match the number of occurrences of `"%s"` in the format string, `Verify` will still
    behave as expected, and will still include all argument values in the error message; the message
    will simply not be formatted exactly as intended.
    
    <h3>More information</h3>
    
    See <a href="https://github.com/google/guava/wiki/ConditionalFailuresExplained">Conditional
    failures explained</a> in the Guava User Guide for advice on when this class should be used.

    Since
    - 17.0
    """

    @staticmethod
    def verify(expression: bool) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with no
        message otherwise.

        Raises
        - VerifyException: if `expression` is `False`

        See
        - Preconditions.checkState Preconditions.checkState()
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, *errorMessageArgs: Tuple["Object", ...]) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.

        Arguments
        - expression: a boolean expression
        - errorMessageTemplate: a template for the exception message should the check fail. The
            message is formed by replacing each `%s` placeholder in the template with an
            argument. These are matched by position - the first `%s` gets `errorMessageArgs[0]`, etc. Unmatched arguments will be appended to the formatted message in
            square braces. Unmatched placeholders will be left as-is.
        - errorMessageArgs: the arguments to be substituted into the message template. Arguments
            are converted to strings using String.valueOf(Object).

        Raises
        - VerifyException: if `expression` is `False`

        See
        - Preconditions.checkState Preconditions.checkState()
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: str) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: str, p2: str) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: str) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: str) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object", p2: str) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: str, p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object", p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: str, p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object", p2: int) -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: str, p2: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: int, p2: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object", p2: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object", p2: "Object", p3: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verify(expression: bool, errorMessageTemplate: str, p1: "Object", p2: "Object", p3: "Object", p4: "Object") -> None:
        """
        Ensures that `expression` is `True`, throwing a `VerifyException` with a
        custom message otherwise.
        
        See .verify(boolean, String, Object...) for details.

        Since
        - 23.1 (varargs overload since 17.0)
        """
        ...


    @staticmethod
    def verifyNotNull(reference: "T") -> "T":
        """
        Ensures that `reference` is non-null, throwing a `VerifyException` with a default
        message otherwise.

        Returns
        - `reference`, guaranteed to be non-null, for convenience

        Raises
        - VerifyException: if `reference` is `null`

        See
        - Preconditions.checkNotNull Preconditions.checkNotNull()
        """
        ...


    @staticmethod
    def verifyNotNull(reference: "T", errorMessageTemplate: str, *errorMessageArgs: Tuple["Object", ...]) -> "T":
        """
        Ensures that `reference` is non-null, throwing a `VerifyException` with a custom
        message otherwise.

        Arguments
        - errorMessageTemplate: a template for the exception message should the check fail. The
            message is formed by replacing each `%s` placeholder in the template with an
            argument. These are matched by position - the first `%s` gets `errorMessageArgs[0]`, etc. Unmatched arguments will be appended to the formatted message in
            square braces. Unmatched placeholders will be left as-is.
        - errorMessageArgs: the arguments to be substituted into the message template. Arguments
            are converted to strings using String.valueOf(Object).

        Returns
        - `reference`, guaranteed to be non-null, for convenience

        Raises
        - VerifyException: if `reference` is `null`

        See
        - Preconditions.checkNotNull Preconditions.checkNotNull()
        """
        ...
